* Author(s)    :  Ricardo Gabriel
* Date         :  02/12/2021
* Update       :  05/01/2022
* Description  :  Creation of dataset for estimations
* Dependencies :  All .dta available in initial_dataset and all defined paths
* Modifications:  
* Products     :  log file and dta files in work_area

* NEW VERSION
* Modifications:  (25/03/2024, João Quelhas, creation of replication package)

*********************************************************
*                       Preamble                        *
*********************************************************

local color "white"
local scale = 1.75

*********************************************************
*               Data for Descriptives                   *
*********************************************************

* Upload the main dataset.
use "${path_work}/annual_dataset/Annual_Contest_Last.dta", clear

* Merge the dataset with the Winners one.
merge m:1 tina using "${path_work}/tinas/Tina_Winners.dta"
drop if _merge == 2
drop _merge

* Merge the dataset with the Losers one.
merge m:1 tina using "${path_work}/tinas/Tina_Losers.dta"
replace winner = 0 if _merge == 3
drop if _merge == 2
drop _merge

* Remove non-participants from the sample.
keep if winner != .

* Adjust sample to include only data from 2009 to 2019.
noi: drop if year < 2009 | year > 2019

* Set the panel with firm identifier and year.
xtset tina year

* Adjust sample to include only private non-financial corporations.
noi: keep if si_final == 348500004

* Adjust sample to include only firms "em atividade" (in activity).
noi: drop if sitempresa > 1

* Adjust sample to include only firms with available information on lagged assets.
noi: drop if l.B001 == . 

* Adjust sample to include only firms with lagged total assets above p1.
noi: sum l.B001,d
noi: drop if l.B001 <= `r(p1)'

* Drop if the lagged value of a firm has no employees.
noi: drop if l.E002 == 0

* Set the panel with firm identifier and year.
xtset tina year

* Create a variable with the industry classification CAE3,
gen industry = real(substr(string(cae3), 1, 2))

* Replace the variable distrito (which gives the district)
* to combine all islands in each island group in a single district,
* Portugal has 18 districts plus 2 island groups,
replace distrito=19 if distrito==20 | distrito==21
replace distrito=22 if distrito==23

* Create a variable location that groups the district.
egen location = group(distrito)

* Create all the required variables related to fundamentals of the firms.
gen age 	 = year - ancon		// age of the firm = current year - founding year
gen total_assets = B001			// total assets
gen ncassets	 = B004			// non-current assets
gen ppe 	 = B012			// fixed tangible assets
gen intangibles  = B005-B012		// intangible assets
gen fin_inv	 = B025			// financial investments
gen cassets	 = B029			// current assets		
gen inventories  = B032			// inventories
gen customers	 = B041			// number of customers
gen cash 	 = B049			// cash
gen liquidity	 = B049/B001		// liquidity = cash / assets
gen depreciation = D041			// expenses/reversals of depreciations and amortizations
gen capex 	 = ncassets - L.ncassets + depreciation // CAPEX
gen liabilities  = B080			// liabilities
gen liabilitiesnc= B081			// non-current liabilities
gen liabilitiesc = B089			// current liabilities
gen suppliers    = B093			// current liabilities (suppliers)	
gen equity       = B060			// equity
gen turnover	 = D001		        // turnover
gen income	 = D021		        // total income
gen profit       = D021 - D062 		// profit = total income - total expenses
gen EBITDA       = D084			// EBITDA
gen totalcosts   = D062			// total expenses
gen compensation = D029			// employee expenses
gen COGS         = D025			// cost of goods sold and material consumed
gen supplies     = D026			// supplies and external services
gen employees	 = E002		        // number of paid employees
gen totalhours	 = E012		        // number of hours worked by paid employees
gen wagepw	 = D029 / employees     // wage per worker = employee expenses / number of paid employees
gen salesperemp	 = turnover / employees // sales per employee = turnover / number of paid employees

* Create a variable that computes the value added for each firm.
* Value added = (turnover + remaining income) 
*               - (costs of goods sold and material consumed
*                 + supplies and external services
*                 + indirect taxes)
gen valueadded	= (D001 + D111) - (D025 + D026 + DL047)
gen valueaddedperemp	= valueadded / employees

* Create a variable that computes the total factor productivity for each firm.
* TFP = e^(ln(valueadded) - 1/3 * ln(non-current assets) - 2/3 * ln(number of hours worked)
gen tfp		= exp(ln(valueadded) - 1/3*ln(ncassets) - 2/3*ln(totalhours))

* Compute the implicit interest rate

* The first step is to remove negative interest payments.
noi: replace D053 = . if D053 <= 0

* Compute the interest rate using different formulas:
** = interest rate expense / credit that a firm used effectively
noi: gen interest  = D053 / valor_efectivo
** = interest rate expense / lag of credit that a firm used effectively
** this is the baseline scenario in the paper
noi: gen interest2 = D053 / l.valor_efectivo
** = interest rate expense / average of credit and lagged credit
noi: gen interest3 = D053 / (valor_efectivo + l.valor_efectivo)/2

* Summarize the variable interest.
noi: sum interest*,d

* Winsorize the variable interest between 10% and 90%.
noi: winsor2 interest, replace cuts(10 90)
* Convert the interest rate to percentage.
replace interest = interest * 100

* Create a variable to have time-industry fixed effects.
egen t_i_FE = group(year industry)       // time-industry fixed effect

* Create key independent variable: size of the award / total assets in t-1
replace award = award / L.B001

* Replace award as nan if the award weight is 0.
noisily replace award = . if award == 0

* Summarize the variable award when it is above 0.
noisily sum award if award > 0, d

* Drop the variable winner.
drop winner

* Generate a new variable winner if the award is not nan.
gen winner = (award!=.)

* Replace award as 0 if award is nan.
noisily replace award = 0 if award ==.

bys tina: egen vencedor = total(award)

replace award = 0  if award ==. & vencedor > 0

* Save the dataset.
save "${path_work}/auxiliary/correlation_descriptives.dta", replace

*********************************************************
*               Data for Descriptives II                *
*********************************************************

* Upload BASE dataset.
use "${path_source}/PM111_A_BASE_BPLIM.dta", clear

* Rename the firm identifier to tina.
rename adjudicatario_tina tina

* Convert the signature date into date format.
replace date_signature = dofm(date_signature)

* Replace year for its lag.
replace year = year-1

* Keep public contests.
noi: keep if inrange(procedimento,5,7)

* Keep positive awards.
noi: keep if preco > 0
rename preco award

* Keep contests with solely one winner.
noi: keep if number_adjudicatarios == 1

* Rename the variable signature date.
rename date_signature date

* Create a variable loser to identity the ones that lost two contests.
gen double loser = concorrentes_tina1 if concorrentes_tina1 != tina & concorrentes_tina2 == tina
replace loser = concorrentes_tina2 if concorrentes_tina2 != tina & concorrentes_tina1 == tina
drop if loser == .

* Remove repeated trios (tina loser year).
duplicates drop tina loser year, force

* Create a variable with contract id.
gen id = _n

* Duplicate observations.
expand 2

* Sort the dataset.
sort id year tina

* Format dataset to have a contract * tina * year dimension.
replace tina = loser if id == id[_n-1]
gen double winner = (tina != loser)
replace loser = (winner==0)
order id tina year winner loser date preco prazo local
keep id tina year winner loser date preco prazo local

* Merge the dataset with firm characteristics dataset.
merge m:m tina using "${path_work}/annual_dataset/Cover_Unique.dta"
drop if _merge == 2
drop _merge
merge m:m tina year using "${path_work}/annual_dataset/Credit_A_Mean.dta"
drop if _merge == 2
drop _merge
merge m:m tina year using "${path_work}/annual_dataset/CBHP_A.dta"
drop if _merge == 2
drop _merge

* Sort the dataset.
sort id loser

* Create a variable with the industry classification CAE3,
gen industry 		= real(substr(string(cae3), 1, 2))

* Replace the variable distrito (which gives the district)
* to combine all islands in each island group in a single district,
* Portugal has 18 districts plus 2 island groups,
replace distrito=19 if distrito==20 | distrito==21
replace distrito=22 if distrito==23
replace distrito=19 if distrito==20 | distrito==21
replace distrito=22 if distrito==23

* Create a variable location that groups the district.
egen location 		= group(distrito)

* Create all the required variables related to fundamentals of the firms.
gen total_assets = B001			// total assets
gen turnover	 = D001		        // turnover
gen employees	 = E002		        // number of paid employees
gen salesperemp	 = turnover / employees // sales per employee = turnover / number of paid employees
gen age 	 = year - ancon		// age of the firm = current year - founding year
gen liquidity	 = B049/B001		// liquidity = cash / assets
gen totalhours	 = E012		        // number of hours worked by paid employees
gen liabilities  = B080			// liabilities

* Create a variable that computes the value added for each firm.
* Value added = (turnover + remaining income) 
*               - (costs of goods sold and material consumed
*                 + supplies and external services
*                 + indirect taxes)
gen valueadded	= (D001 + D111) - (D025 + D026 + DL047)
gen valueaddedperemp	= valueadded / employees

* Save the dataset.
save "${path_work}/auxiliary/procurement_descriptives.dta", replace

*********************************************************
*              Data for LP regressions                  *
*********************************************************

* Annual data
*********************************************************

* Upload data.
use "${path_work}/annual_dataset/Annual_Contest_Last.dta", clear

* Adjust sample to include only data from 2009 to 2019.
noi: drop if year < 2009 | year > 2019

* Adjust sample to include only private non-financial corporations.
noi: keep if si_final == 348500004

* Adjust sample to include only firms "em atividade" (in activity).
noi: drop if sitempresa > 1

* Adjust sample to include only firms with available information on lagged assets.
noi: drop if l.B001 == . 

* Adjust sample to include only firms with lagged total assets above p1.
noi: sum l.B001,d
noi: drop if l.B001 <= `r(p1)'

* Drop if the lagged value of a firm has no employees.
noi: drop if l.E002 == 0

* Set the panel with firm identifier and year.
xtset tina year

* Create a new variable with the weight of the award on lagged total assets.
gen awardx = award / l.B001

* Create a new variable with the percentage change in total assets.
gen change_assets = (B001-l.B001) / l.B001*100

* Plot the two new variables if the award is positive.
scatter change_assets awardx if award > 0

* Export the graph.
*graph export "${path_results}/Figure_scatter1.png", replace
*window manage close graph

* Plot the two new variables if the award is positive and the weight is less than 10.
scatter change_assets awardx if award > 0 & awardx < 10

* Export the graph.
*graph export "${path_results}/Figure_scatter2.png", replace
*window manage close graph

* Compute the p1 and p99 for the weight of the award on lagged total assets.
noi: sum awardx if award>0, d
local xp99 = r(p99)
local xp1  = r(p1)

* Compute the p1 and p99 for the change in total assets.
noi: sum change_assets if award > 0, d
local yp99 = r(p99)
local yp1  = r(p1)

* Plot the two new variables if they are withing p1 and p99 and the award is positive.
scatter change_assets awardx if award > 0 & awardx < `xp99' & change_assets < `yp99' & awardx > `xp1' & change_assets > `yp1'

* Export the graph.
*graph export "${path_results}/Figure_scatter3.png", replace 
*window manage close graph

* Cleaning the awardx variable by trimming it at percentil 1 and 99.
noi: replace awardx = `xp99' if awardx > `xp99' & awardx != .
noi: replace awardx = `xp1'  if awardx < `xp1'  & awardx > 0  & awardx != .
noi: replace awardx = .      if awardx == 0

* Create a variable with the industry classification CAE3,
gen industry = real(substr(string(cae3), 1, 2))

* Replace the variable distrito (which gives the district)
* to combine all islands in each island group in a single district,
* Portugal has 18 districts plus 2 island groups,
replace distrito=19 if distrito==20 | distrito==21
replace distrito=22 if distrito==23

* Create a variable location that groups the district.
egen location = group(distrito)

* Create all the required variables related to fundamentals of the firms.
gen age 	 = year - ancon	        // age of the firm = current year - founding year
gen ncassets	 = B004 		        // non-current assets
gen ppe 	 = B012		        // fixed tangible assets
gen intangibles  = B005 - B012	        // intangible assets	
gen fin_inv	 = B025		        // financial investments
gen cassets	 = B029			// current assets		
gen inventories  = B032			// inventories
gen customers	 = B041			// number of customers
gen cash 	 = B049		        // current assets -> cash and bank deposits
gen depreciation = D041			// expenses/reversals of depreciations and amortizations
gen capex 	 = ncassets - L.ncassets + depreciation // CAPEX
gen liquidity	 = B049/B001		// liquidity = cash / assets
gen liabilities  = B080			// liabilities
gen liabilitiesnc= B081			// non-current liabilities
gen liabilitiesc = B089			// current liabilities
gen suppliers    = B093			// current liabilities (suppliers)	
gen equity       = B060			// equity
gen turnover	 = D001		        // turnover
gen income	 = D021		        // total income
gen profit       = D021 - D062 		// profit = total income - total expenses
gen EBITDA       = D084			// EBITDA
gen totalcosts   = D062			// total expenses
gen compensation = D029			// employee expenses
gen COGS         = D025			// cost of goods sold and material consumed
gen supplies     = D026			// supplies and external services
gen employees	 = E002		        // number of paid employees
gen totalhours	 = E012		        // number of hours worked by paid employees
gen wagepw	 = D029 / employees     // wage per worker = employee expenses / number of paid employees
gen salesperemp	 = turnover / employees // sales per employee = turnover / number of paid employees
gen leverages    = B080 / B001          // leverage = liabilities / assets
gen total_assets = B001

* Create a variable that computes the value added for each firm.
* Value added = (turnover + remaining income) 
*               - (costs of goods sold and material consumed
*                 + supplies and external services
*                 + indirect taxes)
gen valueadded	= (D001 + D111) - (D025 + D026 + DL047)

* Create a variable that computes the total factor productivity for each firm.
* TFP = e^(ln(valueadded) - 1/3 * ln(non-current assets) - 2/3 * ln(number of hours worked)
gen tfp		= exp(ln(valueadded) - 1/3*ln(ncassets) - 2/3*ln(totalhours))

* Compute the implicit interest rate

* The first step is to remove negative interest payments.
noi: replace D053 = . if D053 <= 0

* Compute the interest rate using different formulas:
** = interest rate expense / credit that a firm used effectively
noi: gen interest  = D053 / valor_efectivo
** = interest rate expense / lag of credit that a firm used effectively
** this is the baseline scenario in the paper
noi: gen interest2 = D053 / l.valor_efectivo
** = interest rate expense / average of credit and lagged credit
noi: gen interest3 = D053 / (valor_efectivo + l.valor_efectivo)/2

* Summarize the variable interest.
noi: sum interest*,d

* Winsorize the variable interest between 10% and 90%.
noi: winsor2 interest, replace cuts(10 90)
* Convert the interest rate to percentage.
replace interest = interest * 100

* Winsorize the variable interest2 between 10% and 90%.
noi: winsor2 interest2, replace cuts(10 90)
* Convert the interest rate to percentage.
replace interest2 = interest2 * 100

* Winsorize the variable interest2 between 10% and 90%.
noi: winsor2 interest3, replace cuts(10 90)
* Convert the interest rate to percentage.
replace interest3 = interest3 * 100

* Create a variable to have time-industry fixed effects.
egen t_i_FE = group(year industry)       // time-industry fixed effect

gen award_original = award

* Create key independent variable: size of the award / total assets in t-1
replace award = award / L.B001

* Replace award as nan if the award weight is 0.
noisily replace award = . if award == 0

* Summarize the variable award when it is above 0.
noisily sum award if award > 0, d

bys tina: egen vencedor = total(award)

replace award = 0  if award ==. & vencedor > 0

* Save the dataset.
save "${path_work}/auxiliary/annual_analysis_intensive.dta", replace

* Monthly data
*********************************************************

use "${path_work}/monthly_dataset/Montly_Contest_award.dta", clear

** Cleaning

xtset tina date

gen L12B001 = L12.B001
gen L12E002 = L12.E002

* Adjust sample to include only data from 2009 to 2019.
noi: drop if year < 2009 | year > 2019

* Adjust sample to include only private non-financial corporations.
noi: keep if si_final == 348500004

* Adjust sample to include only firms "em atividade" (in activity).
noi: drop if sitempresa > 1

* Adjust sample to include only firms with available information on lagged assets.
noi: drop if L12B001 == . 

* Adjust sample to include only firms with lagged total assets above p1.
noi: sum L12B001,d
noi: drop if L12B001 <= `r(p1)'

* Drop if any of the 1 lags displays a firm without employees.
noi: drop if L12E002 == 0

* Set the panel with firm identifier and year.
xtset tina date

* Create a variable with the industry classification CAE3,
gen industry = real(substr(string(cae3), 1, 2))

* Replace the variable distrito (which gives the district)
* to combine all islands in each island group in a single district,
* Portugal has 18 districts plus 2 island groups,
replace distrito=19 if distrito==20 | distrito==21
replace distrito=22 if distrito==23

* Create a variable location that groups the district.
egen location = group(distrito)

* Compute the implicit interest rate

* The first step is to remove negative interest payments.
noi: replace D053 = . if D053 <= 0

bys tina year: egen credito = sum(valor_efectivo)
format credito %12.0g
replace credito = credito / 2

sort tina date

* Compute the interest rate using different formulas:
** = interest rate expense / credit that a firm used effectively
noi: gen interest  = D053 / credito
** = interest rate expense / lag of credit that a firm used effectively
** this is the baseline scenario in the paper
noi: gen interest2 = D053 / L12.credito
** = interest rate expense / average of credit and lagged credit
noi: gen interest3 = D053 / (credito + L12.credito)/2

* Summarize the variable interest.
noi: sum interest*,d

* Winsorize the variable interest between 10% and 90%.
noi: winsor2 interest, replace cuts(10 90)
* Convert the interest rate to percentage.
replace interest = interest * 100

* Winsorize the variable interest2 between 10% and 90%.
noi: winsor2 interest2, replace cuts(10 90)
* Convert the interest rate to percentage.
replace interest2 = interest2 * 100

* Winsorize the variable interest2 between 10% and 90%.
noi: winsor2 interest3, replace cuts(10 90)
* Convert the interest rate to percentage.
replace interest3 = interest3 * 100

* Create a variable to have time-industry fixed effects.
egen t_i_FE = group(year industry)       // time-industry fixed effect

gen awardx = award

* Create key independent variable: size of the award / total assets in t-1
replace award = award / L12B001

* Replace award as nan if the award weight is 0.
noisily replace award = . if award == 0
noisily replace awardx = . if awardx == 0

* Summarize the variable award when it is above 0.
noisily sum award if award > 0, d

bys tina: egen vencedor = total(award)

replace award = 0 if award ==. & vencedor > 0

replace awardx = 0 if award ==. & vencedor > 0

* Save the dataset.
save "${path_work}/auxiliary/monthly_analysis_intensive.dta", replace

*********************************************************
