* Author(s)    :  Ricardo Gabriel
* Date         :  30/09/2021
* Update       :  26/11/2023
* Description  :  Merge different datasets to create a unique dataset
* Dependencies :  All .dta available in initial_dataset and all defined paths
* Modifications:  Rewrite data cleaning and merge
* Products     :  log file and dta files in work_area

* NEW VERSION
* Modifications:  (25/03/2024, João Quelhas, creation of replication package)

*********************************************************
*                       Preamble                        *
*********************************************************

local color "white"
local scale = 1.75

*********************************************************
*                   Balance Sheet Data                  *
*********************************************************

* c.f. Central Balance Sheet - Harmonized Panel (CBHP)
* https://doi.org/10.17900/CB.CBHP.Jun2023.V1

* There are 5 main files with different info:

* General Information (Cover Sheet)
*"${path_source}/CBHP_A_YFRM_20062018_JUN20_ROSTO_V01.dta"

* Economic and Financial Information
*"${path_source}/CBHP_A_YFRM_20062018_JUN20_CONTAS_V01.dta"

* Employment Information
*"${path_source}/CBHP_A_YFRM_20062018_JUN20_PESSOAL_V01.dta"

* Trade Information and Markets
*"${path_source}/CBHP_A_YFRM_20062018_JUN20_MG_V01.dta"

* Corporate Actions
*"${path_source}/CBHP_A_YFRM_20062018_JUN20_AMARC_V01.dta"

* Upload Cover Sheet dataset and merge with the other ones.
use "${path_source}/CBHP_A_YFRM_20062021_JUN23_ROSTO_V01.dta", clear

merge m:m tina ano using "${path_source}/CBHP_A_YFRM_20062021_JUN23_CONTAS_V01.dta"
drop _merge
merge m:m tina ano using "${path_source}/CBHP_A_YFRM_20062021_JUN23_PESSOAL_V01.dta"
drop _merge
merge m:m tina ano using "${path_source}/CBHP_A_YFRM_20062021_JUN23_MG_V01.dta"
drop _merge

* Rename the variable year.
rename ano year
format year %9.0g

* Save the merged dataset.
save "${path_work}/annual_dataset/CBHP_A.dta", replace

* Create a smaller dataset and save it with the following variables:
* tina - firm identifier
* year - year of the dataset
* B001 - total assets
* D053 - interest expenses
preserve
keep tina year B001 D053
save "${path_work}/annual_dataset/B001_A.dta", replace
restore

*** Prepare dataset for matching design exercise ***

* Set a panel with id(tina) t(year)
xtset tina year

* Create a variable with the industry classification CAE3,
gen industry = real(substr(string(cae3), 1, 2))

* Replace the variable distrito (which gives the district)
* to combine all islands in each island group in a single district,
* Portugal has 18 districts plus 2 island groups,
replace distrito=19 if distrito==20 | distrito==21
replace distrito=22 if distrito==23

* Create a variable location that groups the district.
egen location = group(distrito)

* Create all the required variables related to fundamentals of the firms.
gen lB001	= l.B001               // lagged total assets
gen ncassets	= B004 		       // non-current assets
gen ppe 	= B012		       // fixed tangible assets
gen depreciation= D041		       // expenses/reversals of depreciations and amortizations
gen capex 	= ncassets - L.ncassets + depreciation  // CAPEX
gen tangibles	= ppe - L.ppe          // change in fixed tangibles assets
gen fin_inv	= B025		       // financial investments
gen age 	= year - ancon	       // age of the firm = current year - founding year
gen cash 	= B049		       // current assets -> cash and bank deposits
gen liabilities = B080		       // liabilities
gen turnover	= D001		       // turnover
gen income	= D021		       // total income
gen employees	= E002		       // number of paid employees
gen totalhours	= E012		       // number of hours worked by paid employees
gen wagepw	= D029 / employees     // wage per worker = employee expenses / number of paid employees
gen salesperemp	= turnover / employees // sales per employee = turnover / number of paid employees

* Create a variable that computes the value added for each firm.
* Value added = (turnover + remaining income) 
*               - (costs of goods sold and material consumed
*                 + supplies and external services
*                 + indirect taxes)
gen valueadded	= (D001 + D111) - (D025 + D026 + DL047)

* Create a variable that computes the total factor productivity for each firm.
* TFP = e^(ln(valueadded) - 1/3 * ln(non-current assets) - 2/3 * ln(number of hours worked)
gen tfp		= exp(ln(valueadded) - 1/3*ln(ncassets) - 2/3*ln(totalhours))

* Create a variable with the interest expenses.
noi: gen interest = D053              

* Replace all the negative interest expenses by zero.
noi: replace interest = . if interest <= 0

* Create a variable to have time-industry fixed effects.
egen t_i_FE = group(year industry)

* Define full list of variables to use as lhsvar.
local creditvarlist ncassets ppe tangibles fin_inv cash liabilities turnover income
local balancevarlist employees totalhours wagepw salesperemp valueadded tfp
local allvarlist `creditvarlist' `balancevarlist'

* Number of years for the horizon (window to estimate).
local horizon = 3
local mh = -3

* Compute forward change of balance sheet variables as growth rate relative to period t-1.
foreach lhsvar in `balancevarlist' {
	
	forvalues i = `mh'(1)`horizon' {
	
		if (`i'<0) {
		
		local ii = `i' + abs(`mh')
		local ll = abs(`i')           
			
			gen `lhsvar'F`ii' = (L`ll'.`lhsvar' - L.`lhsvar')/ L.`lhsvar'
		}
		
		else 	{
		
		local ii = `i' + abs(`mh')
			
			gen `lhsvar'F`ii' = (F`i'.`lhsvar' - L.`lhsvar')/ L.`lhsvar'
		}
	}
}

* Compute forward change of credit variables as growth rate relative to period t-1.
foreach lhsvar in `creditvarlist'{
	
	forvalues i =  `mh'(1)`horizon' {
		
		if (`i'<0) {
			
		local ii = `i' + abs(`mh')
		local ll = abs(`i')
		
			gen `lhsvar'F`ii' = (L`ll'.`lhsvar' - L.`lhsvar')/ L.B001 
		}
	    else 	{
			
		local ii = `i' + abs(`mh')
		
			gen `lhsvar'F`ii' = (F`i'.`lhsvar' - L.`lhsvar')/ L.B001
		}
	}
}

* In order to match on the average of t-1 and t-2 observables replace the variables with the first lag.
foreach lhsvar in `balancevarlist' `creditvarlist' {

	replace `lhsvar' = l1.`lhsvar'

	}

* Save the dataset.
save "${path_work}/annual_dataset/CBHP_Matching_A.dta", replace

*********************************************************
*                  Credit Data (CRC)                    *
*********************************************************

* Upload CRC COVER dataset.
use "${path_source}/CRC_A_FRM_APR19_COVER_V01.dta", clear

* Identify duplicated firm identifiers (tina).
duplicates tag tina, gen(duplicates)
sort duplicates tina maxdate
gen drop = 0
replace drop = 1 if tina == tina[_n+1]

* Keep the latest observation of the duplicates identified.
drop if drop == 1
drop duplicates drop

* Save the dataset with unique firm identifiers.
save "${path_work}/annual_dataset/Cover_Unique.dta", replace 

* Upload CRC COBR dataset from 2007.
* COBR = Firm Level Credit Outstanding & Bank Relationship File 
use "${path_source}/CRC_A_MFRM_2007_APR19_COBR_V01.dta", clear

* Merge with monthly data from 2008 to 2018.
forvalues x = 8/9 {
	append using "${path_source}/CRC_A_MFRM_200`x'_APR19_COBR_V01.dta"
}
forvalues x = 10/18 {
	append using "${path_source}/CRC_A_MFRM_20`x'_APR19_COBR_V01.dta"
}

* Check whether the sum of collateral is equal to the credit effectively borrowed.
noi: gen colateral = valor_g1 + valor_g2 + valor_g3 + valor_g4 +valor_g5 + valor_g6
noi: gen dif = valor_efectivo - colateral
noi: sum dif, d

* If dif > 0, it means that there are firms with unsecured creditvarlist
* In the dataset, d can be negative which means that firms provide more colateral than the borrowing amount.

* If a firm has more colateral than borrowing amount, set it to 0.
* It is a measurement error (data glitch) and should not be taken into account.
noi: gen nocolateral = valor_efectivo - colateral
noi: sum nocolateral, d
noi: replace nocolateral = 0 if nocolateral < 0
drop dif

* valor_g1 Credit secured by real collateral mortgaged
* valor_g2 Credit secured by real collateral not mortgaged
* valor_g3 Credit secured by financial collateral
* valor_g4 Credit secured by personal guarantee provided by firm or individual
* valor_g5 Credit secured by personal guarantee granted by the state or financial institution
* valor_g6 Credit secured by other guarantees

* Add to credit secured the value of the unsecured credit. 
gen valor_g4_ori = valor_g4 + nocolateral
gen valor_g6_ori = valor_g6 + nocolateral

save "${path_work}/annual_dataset/Credit_M.dta", replace

preserve
* Collapse into annual data using the last value of the year.
format date %10.0g
gen date_ = dofm(date)
gen year = year(date_)
drop date date_
order tina year
ds year tina, not
collapse (last) `r(varlist)', by(year tina)

* Set the panel with id(tina) t(year)
xtset tina year

* The most recent date for credit data is August 2018 so no full year information is available.
drop if year >= 2018

* Save the dataset.
save "${path_work}/annual_dataset/Credit_A_Last.dta", replace
restore

preserve
* Collapse into annual data using the mean value over the year.
format date %10.0g
gen date_ = dofm(date)
gen year = year(date_)
drop date date_
order tina year
ds year tina, not
collapse (mean) `r(varlist)', by(year tina)

* Set the panel with id(tina) t(year)
xtset tina year

* The most recent date for credit data is August 2018 so no full year information is available.
drop if year >= 2018

* Save the dataset.
save "${path_work}/annual_dataset/Credit_A_Mean.dta", replace
restore

*** Prepare dataset for matching design exercise ***
* Collect all dependent variables needed.

* Merge the dataset with the smaller dataset (interest expenses).

foreach setting in Mean Last {

	use "${path_work}/annual_dataset/Credit_A_`setting'.dta", clear
	
	merge m:m tina year using "${path_work}/annual_dataset/B001_A.dta"

	* Keep only the observations from the credit dataset.
	drop if _merge == 2  
	drop _merge

	* Set the panel with id(tina) t(year)
	xtset tina year

	* Compute the IMPLICIT INTEREST RATE

	* The first step is to remove negative interest payments as done above.
	noi: replace D053  = . if D053 <= 0

	* Compute the interest rate using different formulas:
	** = interest rate expense / credit that a firm used effectively
	noi: gen interest  = D053 / valor_efectivo
	** = interest rate expense / lag of credit that a firm used effectively
	** this is the baseline scenario in the paper
	noi: gen interest2 = D053 / l.valor_efectivo
	** = interest rate expense / value of the colateral
	noi: gen interest3 = D053 / colateral
	** = interest rate expense / lag of value of the colateral
	noi: gen interest4 = D053 / l.colateral

	* Summarize the variable interest.
	noi: sum interest*,d

	* Winsorize the variable interest between 10% and 90%.
	noi: winsor2 interest, replace cuts(10 90)
	* Convert the interest rate to percentage.
	replace interest = interest * 100

	* Winsorize the variable interest2 between 10% and 90%.
	noi: winsor2 interest2, replace cuts(10 90)
	* Convert the interest rate to percentage.
	replace interest2 = interest2 * 100

	* Winsorize the variable interest3 between 10% and 90%.
	noi: winsor2 interest3, replace cuts(10 90)
	* Convert the interest rate to percentage.
	replace interest3 = interest3 * 100

	* Winsorize the variable interest4 between 10% and 90%.
	noi: winsor2 interest4, replace cuts(10 90)
	* Convert the interest rate to percentage.
	replace interest4 = interest4 * 100

	if ${replication} == 1 {
	
		rename valor_global_p    valor_global
		rename valor_efectivo_p  valor_efectivo
		rename valor_potencial_p valor_potencial
		rename valor_vencido_p   valor_vencido
		rename valor_curto_o_p   valor_curto_o
		rename valor_longo_o_p   valor_longo_o
		rename valor_curto_r_p   valor_curto_r
		rename valor_longo_r_p   valor_longo_r
		
		rename valor_g1_p valor_g1
		rename valor_g2_p valor_g2
		rename valor_g3_p valor_g3
		rename valor_g4_p valor_g4
		rename valor_g5_p valor_g5
		rename valor_g6_p valor_g6

		rename valor_prazo1_r_p valor_prazo1_r
		rename valor_prazo2_r_p valor_prazo2_r
		rename valor_prazo3_r_p valor_prazo3_r
		rename valor_prazo4_r_p valor_prazo4_r
		rename valor_prazo5_r_p valor_prazo5_r
		
		rename valor_prazo1_o_p valor_prazo1_o
		rename valor_prazo2_o_p valor_prazo2_o
		rename valor_prazo3_o_p valor_prazo3_o
		rename valor_prazo4_o_p valor_prazo4_o
		rename valor_prazo5_o_p valor_prazo5_o

	}

	* Define full list of variables to use as lhsvar.
	local creditvarlist valor_global valor_efectivo valor_potencial valor_vencido valor_g1 valor_g2 valor_g3 valor_g4 valor_g5 valor_g6 valor_g4_ori valor_g6_ori valor_curto_o valor_longo_o nocolateral colateral
	local allvarlist `creditvarlist'

	* Number of years for the horizon (window to estimate).
	local horizon = 3
	local mh = -3

	* Compute forward change of credit variables as growth rate relative to period t-1.
	foreach lhsvar in `creditvarlist' {
		
		forvalues i =  `mh'(1)`horizon' {
		    
			if (`i'<0){
			
			local ii = `i' + abs(`mh')
			local ll = abs(`i')
			
				gen `lhsvar'F`ii' = (L`ll'.`lhsvar' - L.`lhsvar') / L.B001
		
			}
		    
			else 	{
			
			local ii = `i' + abs(`mh')
			
				gen `lhsvar'F`ii' = (F`i'.`lhsvar' - L.`lhsvar') / L.B001

			}
		  }
	}

	* Compute forward percentage point difference of interest rate variables relative to period t-1.
	* The interest rates are already in percentage.
	foreach lhsvar in interest interest2 interest3 interest4 {
		
		forvalues i =  `mh'(1)`horizon' {
			
			if (`i'<0){
			
			local ii = `i' + abs(`mh')
			local ll = abs(`i')
				
				gen `lhsvar'F`ii'  = (L`ll'.`lhsvar'  - L.`lhsvar' )
			}
			else {
			
			local ii = `i' + abs(`mh')
				
				gen `lhsvar'F`ii'  = (F`i'.`lhsvar'  - L.`lhsvar' )
			}
		}
	}

	* In order to match on the average of t-1 and t-2 observables replace the variables with the first lag.
	foreach lhsvar in `allvarlist' interest interest2 interest3 interest4 {
		
		replace `lhsvar' = l1.`lhsvar'

		}

	* Drop the variables that are not needed.
	drop B001 D053

	* Save the dataset.
	save "${path_work}/annual_dataset/Credit_Matching_A_`setting'.dta", replace

	}

*********************************************************
*                  Procurement Data                     *
*********************************************************

* Upload BASE dataset.
use "${path_source}/PM111_A_BASE_BPLIM.dta", clear

* Keep public contests.
noi: keep if inrange(procedimento,5,7)

* Keep positive awards.
noi: keep if preco > 0

* Keep contests with solely one winner.
noi: keep if number_adjudicatarios == 1

* Keep awards within the time window 2009-2019.
noi: drop if year < 2009 | year > 2019

* Merge with the dta that contains the cpv code.
merge m:m adjudicatario_tina concorrentes_tina1 concorrentes_tina2 concorrentes_tina3 concorrentes_tina4 concorrentes_tina5 concorrentes_tina6 concorrentes_tina7 concorrentes_tina8 year_ann month_ann procedimento adjudicante_tina number_adjudicatarios date_signature preco prazo number_concorrentes date_fecho preco_total adjudicante_type year month day using "${path_source}/PM111_A_BASE_BPLIM_19042024.dta", force

drop if _merge == 2

* Rename the firm identifier to tina.
rename adjudicatario_tina tina

save "${path_work}/annual_dataset/BASE_dataset.dta", replace

gen cpv_category = substr(cpv_code,1,2)

collapse (sum) preco, by(year tina cpv_category)

egen total_value = total(preco), by(year tina)

bys tina year: gen nr = _N

gen share = preco / total_value

bys tina year: gen flag = 1  if share > 0.5

gen cpv_flag = cpv_category if flag == 1

collapse (sum) preco (firstnm) cpv_flag, by(year tina)

sort tina year

drop preco

save "${path_work}/annual_dataset/auxiliary_industry.dta", replace

****

* Upload BASE dataset.
use "${path_work}/annual_dataset/BASE_dataset.dta", clear

* Convert the signature date into date format.
replace date_signature = dofm(date_signature)

** Save different datasets according to chosen strategy.

* Identification 1: Public Contests (matching)

preserve

* Create a contract level dataset, filtering for contracts where n = 2.
keep if number_concorrentes > 0

* Crete a variable with the current number of observation.
gen contract = _n

* Order the variable contract.
order contract

* Drop the winner firm identifier.	
drop adjudicante_tina

* Rename the firm identifier to tina_concorrente0.
rename tina tina_concorrentes0

* Reshape the dataset to have the contract number and the firm identifiers.
reshape long tina_concorrentes, i(contract) j(tina)

* Create a variable named winner contracts with a winner firm identifier.
gen winner = (tina==0)

* Drop the variable tina.
drop tina

* Drop if the the contract as no contestants other than the winner.
drop if tina_concorrentes == .
rename	tina_concorrentes tina

* Keep needed variables.
keep contract tina winner year month preco prazo local number_concorrentes date_fecho preco_total adjudicante_type

* Rename the variable preco.
rename preco award

* Sort the dataset.
sort contract winner tina year

* Save the dataset.
save "${path_work}/annual_dataset/Procurement_Matching_A.dta", replace

restore

* Identification 2: Public Contests (time series)

preserve

* Keep needed variables.
noi: keep tina year month preco prazo local number_concorrentes date_fecho preco_total adjudicante_type

* Collapse monthly awards, computing the sum of awards and the mean of days to deadline. 
collapse (sum) preco (mean) prazo (mean) number_concorrentes, by(year month tina)

* Summarize the variable preco (awards)
noi: sum preco, d

* Create a variable date with year and month and format it.
gen date = ym(year,month)
format date %tm

* Rename the variable preco as award.
rename preco award
label variable award "Monthly aggregate of procurement revenues announced"

* Set the panel with the firm identifier and the date (year, month)
xtset tina date

* Save the dataset.
save "${path_work}/annual_dataset/Procurement_Contest_M.dta", replace

** Save the annual version of the dataset.

* Replace prazo if it is more than 10 years.
replace prazo = 3650 if prazo > 3650

* Collapse yearly awards, computing the sum of awards and the mean of days to deadline. 
collapse (sum) award (mean) prazo (mean) number_concorrentes, by(year tina)
label variable award "Annual aggregate of procurement revenues announced"

* Summarize the variable award.
noi: sum award, d

* Merge with the industry classification.
merge 1:1 tina year using "${path_work}/annual_dataset/auxiliary_industry.dta"

drop _merge

* Set the panel with the firm identifier and the date (year)
xtset tina year

* Save the dataset.
save "${path_work}/annual_dataset/Procurement_Contest_A.dta", replace

restore

*********************************************************
*                    Annual Dataset                     *
*********************************************************

* Merge annual procurement data with credit data for matching exercise.
use "${path_work}/annual_dataset/Procurement_Matching_A.dta", clear

merge m:m tina using "${path_work}/annual_dataset/Cover_Unique.dta"
drop if _merge == 2
drop _merge
merge m:m tina year using "${path_work}/annual_dataset/CBHP_Matching_A.dta"
drop if _merge == 2
drop _merge
noi: merge m:m tina year using "${path_work}/annual_dataset/Credit_Matching_A_Mean.dta"
drop if _merge == 2
drop _merge
order contract winner tina year award
sort contract winner
save "${path_work}/annual_dataset/Annual_Matching_Contest.dta", replace

* Merge annual procurement data with credit data (main dataset).
use "${path_work}/annual_dataset/CBHP_A.dta", clear
format year %9.0g
merge m:m tina using "${path_work}/annual_dataset/Cover_Unique.dta"
keep if _merge == 3
drop _merge
merge 1:1 tina year using "${path_work}/annual_dataset/Credit_A_Last.dta"
drop if _merge == 2
drop _merge
merge m:m tina year using "${path_work}/annual_dataset/Procurement_Contest_A.dta"
drop if _merge == 2
drop _merge
order tina year award
replace award = 0 if award == .
xtset tina year
save "${path_work}/annual_dataset/Annual_Contest_Last.dta", replace

* Merge annual procurement data with credit data (main dataset).
use "${path_work}/annual_dataset/CBHP_A.dta", clear
format year %9.0g
merge m:m tina using "${path_work}/annual_dataset/Cover_Unique.dta"
keep if _merge == 3
drop _merge
merge 1:1 tina year using "${path_work}/annual_dataset/Credit_A_Mean.dta"
drop if _merge == 2
drop _merge
merge m:m tina year using "${path_work}/annual_dataset/Procurement_Contest_A.dta"
drop if _merge == 2
drop _merge
order tina year award
replace award = 0 if award == .
xtset tina year
save "${path_work}/annual_dataset/Annual_Contest_Mean.dta", replace

*********************************************************
*                   Monthly Dataset                     *
*********************************************************

* Upload Cover Sheet dataset and merge with the other ones.
use "${path_source}/CBHP_A_YFRM_20062021_JUN23_ROSTO_V01.dta", clear
merge m:m tina ano using "${path_source}/CBHP_A_YFRM_20062021_JUN23_CONTAS_V01.dta"
drop _merge
merge m:m tina ano using "${path_source}/CBHP_A_YFRM_20062021_JUN23_PESSOAL_V01.dta"
drop _merge
merge m:m tina ano using "${path_source}/CBHP_A_YFRM_20062021_JUN23_MG_V01.dta"
drop _merge

* Rename the variable year.
rename ano year

* Save the merged dataset.
save "${path_work}/monthly_dataset/CBHP_A.dta", replace

* Create a smaller dataset and save it with the following variables:
* tina - firm identifier
* year - year of the dataset
* B001 - total assets
* D053 - interest expenses
preserve
keep tina year B001 D053 sitempresa E002 distrito
save "${path_work}/monthly_dataset/B001_A.dta", replace
restore

* Upload CRC COVER dataset.
use "${path_source}/CRC_A_FRM_APR19_COVER_V01.dta", clear

* Identify duplicated firm identifiers (tina).
duplicates tag tina, gen(duplicates)
sort duplicates tina maxdate
gen drop = 0
replace drop = 1 if tina == tina[_n+1]

* Keep the latest observation of the duplicates identified.
drop if drop == 1
drop duplicates drop

* Save the dataset with unique firm identifiers.
save "${path_work}/monthly_dataset/Cover_Unique.dta", replace 

* Upload CRC COBR dataset from 2007.
* COBR = Firm Level Credit Outstanding & Bank Relationship File 
use "${path_source}/CRC_A_MFRM_2007_APR19_COBR_V01.dta", clear

* Merge with monthly data from 2008 to 2018.
forvalues x = 8/9 {
	append using "${path_source}/CRC_A_MFRM_200`x'_APR19_COBR_V01.dta"
}
forvalues x = 10/18 {
	append using "${path_source}/CRC_A_MFRM_20`x'_APR19_COBR_V01.dta"
}

* Check whether the sum of collateral is equal to the credit effectively borrowed.
noi: gen colateral = valor_g1 + valor_g2 + valor_g3 + valor_g4 +valor_g5 + valor_g6
noi: gen dif = valor_efectivo - colateral
noi: sum dif, d

* If dif > 0, it means that there are firms with unsecured creditvarlist
* In the dataset, d can be negative which means that firms provide more colateral than the borrowing amount.

* If a firm has more colateral than borrowing amount, set it to 0.
* It is a measurement error (data glitch) and should not be taken into account.
noi: gen nocolateral = valor_efectivo - colateral
noi: sum nocolateral, d
noi: replace nocolateral = 0 if nocolateral < 0
drop dif

* valor_g1 Credit secured by real collateral mortgaged
* valor_g2 Credit secured by real collateral not mortgaged
* valor_g3 Credit secured by financial collateral
* valor_g4 Credit secured by personal guarantee provided by firm or individual
* valor_g5 Credit secured by personal guarantee granted by the state or financial institution
* valor_g6 Credit secured by other guarantees

* Add to credit secured the value of the unsecured credit. 
gen valor_g4_ori = valor_g4 + nocolateral
gen valor_g6_ori = valor_g6 + nocolateral

* Set the panel with id(tina) t(month)
xtset tina date

* Save the dataset.
save "${path_work}/monthly_dataset/Credit_M.dta", replace

* Upload BASE dataset.
use "${path_source}/PM111_A_BASE_BPLIM_19042024.dta", clear

* Rename the firm identifier to tina.
rename adjudicatario_tina tina

* Convert the signature date into date format.
replace date_signature = dofm(date_signature)

* Summarize the variable procedimento (procedures)
noi: sum procedimento

* Keep public contests.
noi: keep if inrange(procedimento,5,7)

* Keep positive awards.
noi: keep if preco > 0

* Keep contests with solely one winner.
noi: keep if number_adjudicatarios == 1

* Keep needed variables.
noi: keep tina year month preco prazo local number_concorrentes date_fecho preco_total adjudicante_type

* Collapse monthly awards, computing the sum of awards and the mean of days to deadline. 
collapse (sum) preco (mean) prazo, by(year month tina)

* Summarize the variable preco (awards)
noi: sum preco, d

* Create a variable date with year and month and format it.
gen date = ym(year,month)
format date %tm

* Rename the variable preco as award.
rename preco award
label variable award "Monthly aggregate of procurement revenues announced"

* Set the panel with the firm identifier and the date (year, month)
xtset tina date

* Save the dataset.
save "${path_work}/monthly_dataset/Procurement_Contest_M.dta", replace

* Merge annual procurement data with credit data (main dataset).

*** Prepare dataset for matching design exercise ***
* Collect all dependent variables needed.

use "${path_work}/monthly_dataset/Credit_M.dta", clear
merge m:m tina date using "${path_work}/monthly_dataset/Procurement_Contest_M.dta"
drop if _merge == 2
drop _merge
drop year
gen year = year(dofm(date))
merge m:m tina year using "${path_work}/monthly_dataset/B001_A.dta"
drop if _merge == 2
drop _merge
merge m:m tina using "${path_work}/monthly_dataset/Cover_Unique.dta"
drop if _merge == 2
drop _merge
order tina date award
replace award = 0 if award == .
xtset tina date
save "${path_work}/monthly_dataset/Monthly_Contest.dta", replace

use "${path_work}/monthly_dataset/Monthly_Contest.dta", clear
collapse (sum) award, by(tina)
keep if award > 0
drop award
save "${path_work}/monthly_dataset/collapsed_monthly.dta", replace

use "${path_work}/monthly_dataset/Monthly_Contest.dta", clear
merge m:1 tina using "${path_work}/monthly_dataset/collapsed_monthly.dta"
keep if _merge == 3
drop _merge
save "${path_work}/monthly_dataset/Montly_Contest_award.dta", replace

*********************************************************
*           Produce List of Winners and Losers          *
*********************************************************

* Upload BASE dataset.
use "${path_source}/PM111_A_BASE_BPLIM_19042024.dta", clear

* Rename the variable.
rename adjudicatario_tina tina

* Format the siganture date as date.
replace date_signature = dofm(date_signature)

* Keep public contests.
keep if inrange(procedimento,5,7)

** Generate winners list.
preserve

* Keep the firm identifier.
keep tina

* Drop duplicates.
duplicates drop tina, force

*Sort the firm identifier.
sort tina

* Generate a dummy for the winner.
gen winner = 1

* Save the dataset.
save "${path_work}/tinas/Tina_Winners.dta", replace

restore

** Generate losers list.

* Keep the firm identifier and other contestants.
keep concorrentes_tina*

* Generate an id.
gen obs = _n

* Reshape the dataset.
reshape long concorrentes_tina, i(obs) j(conc)

* Rename the contestants firm identifier.
rename concorrentes_tina tina

* Generate variable losers.
gen long losers = tina

* Drop variables not needed.
drop obs conc
drop if tina==.

* Drop duplicates.
duplicates drop tina, force

*Sort the dataset.
sort tina

* Merge the dataset with winners to exclude those.
merge 1:1 tina using "${path_work}/tinas/Tina_Winners.dta"

* Keep only the ones that are not winners.
keep if _merge==1
drop _merge losers

* Save the dataset.
save "${path_work}/tinas/Tina_Losers.dta", replace

*********************************************************
