* Author(s)    :  Ricardo Gabriel
* Date         :  02/12/2021
* Update       :  05/01/2022
* Description  :  Create descriptive statistics
* Dependencies :  All .dta available in initial_dataset and all defined paths
* Modifications:  
* Products     :  log file and dta files in work_area

* NEW VERSION
* Modifications:  (25/03/2024, João Quelhas, creation of replication package)

*********************************************************
*                      Graphs Style                     *
*********************************************************

grstyle init
grstyle set plain, nogrid box noextend
grstyle yesno draw_major_vgrid yes
grstyle graphsize x 12
grstyle graphsize y 6
grstyle color background white

*********************************************************
*                       Preamble                        *
*********************************************************

local color "white"
local scale = 1.75

*********************************************************
*  TABLE 1: Summary Statistics of Procurement Contracts *
*********************************************************

* Public Contests

* Upload BASE dataset.
use "${path_source}/PM111_A_BASE_BPLIM.dta", clear

* Rename the firm identifier to tina.
rename adjudicatario_tina tina

* Convert the signature date into date format.
replace date_signature = dofm(date_signature)

* Keep constest between 2009 and 2019.
keep if year >= 2009 & year <= 2019

* Keep public contests.
keep if inrange(procedimento, 5, 7)

* Rename the variable preco.
rename preco award

* Adjust the contests with more than 10 years as deadline.
replace prazo = 3650 if prazo > 3650

* Add 1 to number_concorrentes to account for the winner as well.
replace number_concorrentes = number_concorrentes + 1

* Compute summary statistics of Public Contests
tabstat award prazo number_concorrentes, stats(mean sd p5 median p95 n) save
matrix list r(StatTotal)

* Transpose the matrix containing statistics
matrix transposed_stats = r(StatTotal)'
matrix list transposed_stats

putexcel set "${path_results}/tables/Table_1.xlsx", modify
putexcel B3 = matrix(transposed_stats) 
putexcel close

**********************************************************
** TABLE A.2: Summary statistics for each group of firms *
**********************************************************

putexcel set "${path_results}/tables/Table_A2.xlsx", modify

* Upload the cleaned procurement dataset.
use "${path_work}/auxiliary/annual_analysis_intensive.dta", clear

gen fixed_assets = B004
replace award_original = 0 if award_original  == .

replace interest =  interest / 100

if ${replication} == 1 {
	
	rename valor_global_p    valor_global
	rename valor_efectivo_p  valor_efectivo
	rename valor_potencial_p valor_potencial
	rename valor_vencido_p   valor_vencido
	rename valor_curto_o_p   valor_curto_o
	rename valor_longo_o_p   valor_longo_o
	rename valor_curto_r_p   valor_curto_r
	rename valor_longo_r_p   valor_longo_r
	
	rename valor_g1_p valor_g1
	rename valor_g2_p valor_g2
	rename valor_g3_p valor_g3
	rename valor_g4_p valor_g4
	rename valor_g5_p valor_g5
	rename valor_g6_p valor_g6

	rename valor_prazo1_r_p valor_prazo1_r
	rename valor_prazo2_r_p valor_prazo2_r
	rename valor_prazo3_r_p valor_prazo3_r
	rename valor_prazo4_r_p valor_prazo4_r
	rename valor_prazo5_r_p valor_prazo5_r
	
	rename valor_prazo1_o_p valor_prazo1_o
	rename valor_prazo2_o_p valor_prazo2_o
	rename valor_prazo3_o_p valor_prazo3_o
	rename valor_prazo4_o_p valor_prazo4_o
	rename valor_prazo5_o_p valor_prazo5_o

}

local varlist fixed_assets turnover liquidity liabilities employees wagepw award_original valor_global valor_efectivo valor_potencial valor_vencido valor_g1 valor_g2 valor_g3 valor_g4 valor_g5 valor_g6 interest

preserve

* Create tables for the generic descriptives of winners.
tabstat `varlist' if award_original > 0, stats(mean sd p10 median p90 n) save
matrix list r(StatTotal)

* Transpose the matrix containing statistics
matrix transposed_stats = r(StatTotal)'
matrix list transposed_stats
putexcel C4 = matrix(transposed_stats) 

* Create tables for the generic descriptives of losers.
tabstat `varlist' if award_original == 0, stats(mean sd p10 median p90 n) save
matrix list r(StatTotal)

* Transpose the matrix containing statistics
matrix transposed_stats = r(StatTotal)'
matrix list transposed_stats
putexcel J4 = matrix(transposed_stats) 

putexcel close

restore

*********************************************************
** TABEL A.3: Public procurement contracts:             *
** sample cleaning                                      *
*********************************************************

putexcel set "${path_results}/tables/Table_A3.xlsx", modify

* Upload BASE dataset.
use "${path_source}/PM111_A_BASE_BPLIM.dta", clear

* Rename the firm identifier to tina.
rename adjudicatario_tina tina

* Convert the signature date into date format.
replace date_signature = dofm(date_signature)
sum tina
return list
local obs = r(N)
putexcel D4 = (`obs')

* Keep constest between 2009 and 2019.
keep if year >= 2009 & year <= 2019
sum tina
return list
local obs = r(N)
putexcel D5 = (`obs')

* Keep public contests.
noi: keep if inrange(procedimento,5,7)
sum tina
return list
local obs = r(N)
putexcel D6 = (`obs')

* Keep positive awards.
noi: keep if preco > 0
sum tina
return list
local obs = r(N)
putexcel D7 = (`obs')

* Keep contests with solely one winner.
noi: keep if number_adjudicatarios == 1
sum tina
return list
local obs = r(N)
putexcel D8 = (`obs')

* Upload the merged dataset.
use "${path_work}/annual_dataset/Annual_Contest_Last.dta", clear

* Adjust sample to include only data from 2009 to 2019.
noi: drop if year < 2009 | year > 2019
noi: sum tina if award>0, d
return list
local obs = r(N)
putexcel D9 = (`obs')

* Adjust sample to include only private non-financial corporations.
noi: keep if si_final == 348500004
noi: sum tina if award>0, d
return list
local obs = r(N)
putexcel D10 = (`obs')

* Adjust sample to include only firms "em atividade" (in activity).
noi: drop if sitempresa > 1
noi: sum tina if award>0, d
return list
local obs = r(N)
putexcel D11 = (`obs')

* Adjust sample to include only firms with available information on lagged assets.
noi: drop if l.B001 == . 
noi: sum tina if award>0, d
return list
local obs = r(N)
putexcel D12 = (`obs')

* Adjust sample to drop firms with negative or no total assets.
noi: drop if l.B001 <= 0 
noi: sum tina if award>0, d
return list
local obs = r(N)
putexcel D13 = (`obs')

* Adjust sample to include only firms with lagged total assets above p1.
noi: sum l.B001,d
return list
local pone = r(p1)
putexcel F13 = (`pone')

noi: sum l.B001,d
noi: drop if l.B001 <= `r(p1)'

noi: sum tina if award>0, d
return list
local obs = r(N)
putexcel D14 = (`obs')

* Drop if any of the 3 lags displays a firm without employees.
noi: drop if l.E002 == 0
noi: sum tina if award>0, d
return list
local obs = r(N)
putexcel D15 = (`obs')
putexcel close

*********************************************************
*  TABLE C.1: Winners versus Losers of Public Contests  *
*********************************************************

use "${path_source}/PM111_A_BASE_BPLIM.dta", clear

* Rename the firm identifier to tina.
rename adjudicatario_tina tina

* Convert the signature date into date format.
replace date_signature = dofm(date_signature)

replace year = year-1

* Keep public contests.
noi: keep if inrange(procedimento,5,7)

* Keep positive awards.
noi: keep if preco > 0

* Keep contests with solely one winner.
noi: keep if number_adjudicatarios == 1

* Create a contract level dataset, filtering for contracts where n = 2.
keep if number_concorrentes == 2

gen double loser = concorrentes_tina1 if concorrentes_tina1 != tina & concorrentes_tina2 == tina

replace loser = concorrentes_tina2 if concorrentes_tina2 != tina & concorrentes_tina1 == tina

drop if loser == .

* remove repeated trios (tina loser year)
duplicates drop tina loser year, force

* gen contract id
gen id = _n

* duplicate observations
expand 2

sort id year tina

* adjust dataset to contract * tina * year dimension
replace tina = loser if id == id[_n-1]
gen double winner = (tina != loser)
replace loser = (winner==0)
order id tina year winner loser preco prazo local
keep id tina year winner loser preco prazo local

* merge with firm characteristics
merge m:m tina using "${path_work}/annual_dataset/Cover_Unique.dta"
drop if _merge == 2
drop _merge
merge m:m tina year using "${path_work}/annual_dataset/Credit_A_Last.dta"
drop if _merge == 2
drop _merge
merge m:m tina year using "${path_work}/annual_dataset/CBHP_A.dta"
drop if _merge == 2
drop _merge

sort id loser

* Create a variable with the industry classification CAE3,
gen industry = real(substr(string(cae3), 1, 2))

* Replace the variable distrito (which gives the district)
* to combine all islands in each island group in a single district,
* Portugal has 18 districts plus 2 island groups,
replace distrito=19 if distrito==20 | distrito==21
replace distrito=22 if distrito==23

* Create a variable location that groups the district.
egen location = group(distrito)

* Create all the required variables related to fundamentals of the firms.
gen age 	 = year - ancon		// age of the firm = current year - founding year
gen total_assets = B001			// total assets
gen customers	 = B041			// number of customers
gen cash 	 = B049			// cash
gen liquidity	 = B049/B001		// liquidity = cash / assets
gen liabilities  = B080			// liabilities
gen employees	 = E002		        // number of paid employees
gen totalhours	 = E012		        // number of hours worked by paid employees
gen turnover	 = D001		        // turnover
gen salesperemp	 = turnover / employees // sales per employee = turnover / number of paid employees

* Create a variable that computes the value added for each firm.
* Value added = (turnover + remaining income) 
*               - (costs of goods sold and material consumed
*                 + supplies and external services
*                 + indirect taxes)
gen valueadded	= (D001 + D111) - (D025 + D026 + DL047)
gen valueaddedperemp	= valueadded / employees

local varlist total_assets turnover valueadded employees age liquidity totalhours liabilities valor_global valor_efectivo valor_potencial valor_curto_o valor_longo_o

preserve

* Generic Descriptives
putexcel set "${path_results}/tables/Table_C1.xlsx", modify
tabstat `varlist' if winner == 1, stats(mean median) save
matrix list r(StatTotal)

* Transpose the matrix containing statistics
matrix transposed_stats = r(StatTotal)'
matrix list transposed_stats
putexcel C4 = matrix(transposed_stats) 

tabstat `varlist' if loser == 1, stats(mean median) save
matrix list r(StatTotal)

* Transpose the matrix containing statistics
matrix transposed_stats = r(StatTotal)'
matrix list transposed_stats
putexcel F4 = matrix(transposed_stats) 

restore

* Trick for "time" dimension to easily get differences for each contract
gen t = winner
replace t = 2 if loser == 1
xtset id t
local varlist total_assets turnover valueadded employees age liquidity totalhours liabilities valor_global valor_efectivo valor_potencial valor_curto_o valor_longo_o
* Compute differences
foreach var in `varlist' {
	
	gen dif_`var' = d.`var'

	}

tabstat dif_*, stats(mean median n) save

local diflist dif_total_assets dif_turnover dif_valueadded dif_employees dif_age dif_liquidity dif_totalhours dif_liabilities dif_valor_global dif_valor_efectivo dif_valor_potencial dif_valor_curto_o dif_valor_longo_o
local row = 4
foreach var in `diflist' {
	
	ttest `var' == 0
	
	return list
	
	local obs = r(N_1)
	putexcel J`row' = (`obs')
	
	local obs = r(p)
	putexcel I`row' = (`obs')
	
	local row = `row' + 1

	}
putexcel close

*********************************************************
** FIGURE C.1: Correlation between winning a public     *
** contest and predetermined firm characteristics.      *
*********************************************************

* Upload data.
use "${path_work}/auxiliary/correlation_descriptives.dta", clear

********************
*    Preamble      *
********************

* Define full list of variables to use.
local varlist turnover valueadded liabilities interest valor_global valor_efectivo valor_potencial valor_vencido valor_curto_o valor_longo_o

* Replace each variable as the weight on total assets.
foreach var in `varlist'{
	
	replace `var' = `var'/total_assets

	}

* Use the log of total assets.
replace total_assets = log(total_assets)

* Use the log of employees.
replace employees    = log(employees)

* Label the variable total_assets as log(Assets)
la var total_assets  "log(Assets)"

* Redefine full list of variables to use.
local varlist total_assets turnover valueadded employees salesperemp valueaddedperemp liquidity winner totalhours liabilities interest valor_global valor_efectivo valor_potencial valor_vencido valor_curto_o valor_longo_o

********************
*     coefplot     *
********************

eststo clear

*reghdfe winner `varlist', absorb(tina t_i_FE) vce(cluster tina) 
*eststo multivariate

** Conditional correlation

* Iterate through each variable in the list defined above.
foreach var in `varlist'{
	
	* Run regression with winner as dependent variable and
	* and the lag of the variable being used as independent, 
	* absorbing for firm and time-industry fixed effect s and clustering.
	reghdfe winner l.`var', absorb(tina t_i_FE) vce(cluster tina year)

	* Store the results of the regression.
	eststo `var'

	}

** Unconditional correlation

foreach var in `varlist'{
	
	* Run regression with winner as dependent variable and
	* and the lag of the variable being used as independent, 
	* without fixed effects and clustering.
	reghdfe winner l.`var', noabsorb vce(cluster tina year)
	
	* Store the results of the regression.
	eststo `var'2

	}

* Define the graph design.
* set scheme s2mono

* Labels to be used in the graph.
la var total_assets "log(Assets)"
la var turnover "Sales"
la var valueadded "Value Added"
la var employees "log(Employees)"
*la var age "Firm Age"
la var liquidity "Cash/Assets"
la var liabilities "Liabilities/Assets"
la var valor_global "Total Credit/Assets"

** PANEL (a) Real variables.

* Plot the coefficients of the real variables.
coefplot (total_assets \ turnover \ valueadded \ liquidity \ liabilities \ valor_global, label(Conditional)) (total_assets2 \ turnover2 \ valueadded2 \ liquidity2 \ liabilities2 \ valor_global2, label(Unconditional)), drop(_cons L.winner L.age) xline(0) ci(99) ciopts(recast(rcap)) legend(pos(6) row(1)) xlabel(-0.1(0.05)0.2) yscale(lwidth(none)) xscale(lwidth(none))

* Export the graph.
graph export "${path_results}/figures/figure_c_1/real_variables.pdf", replace

* Labels to be used in the graph.
la var valor_efectivo "Total Used Credit/Assets"
la var valor_potencial "Total Potential Credit/Assets"
la var valor_vencido "Overdue Credit/Assets"
la var valor_longo_o "Long Maturity Credit/Assets"
la var valor_curto_o "Short Maturity Credit/Assets"

** PANEL (b) Financial variables.

* Plot the coefficients of the financial variables.
coefplot (valor_global \valor_efectivo \valor_potencial \valor_curto_o \valor_longo_o \winner, label(Conditional)) (valor_global2 \valor_efectivo2 \valor_potencial2 \valor_curto_o2 \valor_longo_o2 \winner2, label(Unconditional)), drop(_cons) xline(0) ci(99) ciopts(recast(rcap)) legend(pos(6) row(1)) xlabel(-0.1(0.1)0.7) yscale(lwidth(none)) xscale(lwidth(none))

* Export the graph.
graph export "${path_results}/figures/figure_c_1/credit_variables.pdf", replace

*********************************************************
