* Author(s)    :  Ricardo Gabriel
* Date         :  30/09/2021
* Update       :  21/09/2022
* Description  :  Master file where one can run all necessary do files
* Dependencies :  All .dta available in initial_dataset, all define paths, and all do files in the work_area
* Modifications:  Super Master File running all codes I need to produce all figures I need.
* Products     :  Log files, png figures, latex files in results folder. Dta files in work_area.

* NEW VERSION
* Modifications:  (25/03/2024, João Quelhas, creation of replication package)

*********************************************************
*                   Initialization                      *
*********************************************************

version 17
clear all 
program drop _all 
set more off
set rmsg on
capture log close

set maxvar 120000, permanently
set max_memory .

*********************************************************
*               Define project and paths                *
*	       Comment before replication		*
*********************************************************
                              
* Set the path for the data source.
global path_source "/bplimext/projects/r111_QuelhasGabriel/initial_dataset"
*Set the path for the work_area.
global path_work "/bplimext/projects/r111_QuelhasGabriel/work_area"
*Set the path of results to be extracted.
global path_results "/bplimext/projects/r111_QuelhasGabriel/results"
*Set the path for the tools.
global path_tools "/bplimext/projects/r111_QuelhasGabriel/tools"

adopath + "bplimext/projects/r111_QuelhasGabriel/tools"

global data_type       "P"
global data_type_BASE  "S"

global replication     1 // 1 if running on perturbed files, 0 otherwise

*********************************************************
*               Create the log file                     *
*********************************************************

* Create a log file in the work area.                   
* where "logexample" is the log requested for extraction
log using "${path_results}/Master.log", replace

*********************************************************
*               Create the folders                      *
*********************************************************

local datafiles: dir "${path_work}/annual_dataset/" files "*.dta"

foreach datafile of local datafiles {
	capture rm "${path_work}/annual_dataset/`datafile'"	
}

local datafiles: dir "${path_work}/monthly_dataset/" files "*.dta"

foreach datafile of local datafiles {
	capture rm "${path_work}/monthly_dataset/`datafile'"	
}

local datafiles: dir "${path_work}/tinas/" files "*.dta"

foreach datafile of local datafiles {
	capture rm "${path_work}/tinas/`datafile'"	
}

local datafiles: dir "${path_work}/auxiliary/" files "*.dta"

foreach datafile of local datafiles {
	capture rm "${path_work}/auxiliary/`datafile'"	
}

local datafiles: dir "${path_work}/nuts/" files "*.dta"

foreach datafile of local datafiles {
	capture rm "${path_work}/nuts/`datafile'"	
}

capture mkdir "${path_work}/annual_dataset"
capture mkdir "${path_work}/monthly_dataset"
capture mkdir "${path_work}/tinas"
capture mkdir "${path_work}/auxiliary"
capture mkdir "${path_work}/nuts"

capture mkdir "${path_results}/figures"
capture mkdir "${path_results}/figures/figure_1"
capture mkdir "${path_results}/figures/figure_2"
capture mkdir "${path_results}/figures/figure_3"
capture mkdir "${path_results}/figures/figure_4"
capture mkdir "${path_results}/figures/figure_5"
capture mkdir "${path_results}/figures/figure_6"
capture mkdir "${path_results}/figures/figure_c_1/"
capture mkdir "${path_results}/figures/figure_c_2"

capture mkdir "${path_results}/tables"
capture mkdir "${path_results}/tables/Table_2"
capture mkdir "${path_results}/tables/Table_C2"
capture mkdir "${path_results}/tables/Table_C3"

*********************************************************
*                      Run files                        *
*********************************************************

* Datasets Construction
do "${path_work}/dataset_construction"

erase "${path_work}/monthly_dataset/Credit_M.dta"
erase "${path_work}/monthly_dataset/CBHP_A.dta"
erase "${path_work}/monthly_dataset/B001_A.dta"
erase "${path_work}/monthly_dataset/Cover_Unique.dta"

erase "${path_work}/annual_dataset/CBHP_Matching_A.dta"
erase "${path_work}/annual_dataset/Credit_M.dta"
erase "${path_work}/annual_dataset/B001_A.dta"
erase "${path_work}/annual_dataset/Credit_Matching_A_Mean.dta"
erase "${path_work}/annual_dataset/Credit_Matching_A_Last.dta"

* Datasets Cleaning
do "${path_work}/dataset_cleaning"

* Descriptives
do "${path_work}/dataset_descriptives"

* outputs:

** Table    1: Summary Statistics of Procurement Contracts.
** Table  A.2: Summary Statistics for each group of firms.
** Table  A.3: Public procurement contracts: sample cleaning.
** Table  C.1: Winners versus Losers of Public Contests.
** Figure C.1: Correlation between winning a public contest and predetermined firm characteristics.

do "${path_work}/regression_annual"

* outputs:

** Figure  1: Elasticity of firm credit to procurement contract awards.
** Figure  2: Elasticity of interest rates to procurement contract awards.
** Figure  3: Elasticity of credit lines and liquidity to procurement contract awards.
** Figure  6: The effects of procurement contract awards on other firm dynamics.
** Table C.2: Credit, Interest Rates, and Cash responses.

do "${path_work}/regression_monthly"

* outputs:

** Figure 4: The effects of winning procurement awards on firm credit.
** Figure 5: The effects of winning procurement awards on firm collateral.

do "${path_work}/regression_lp_did"

* outputs:

* Figure C.2: Effects of public procurement using contest losers as counterfactual.

do "${path_work}/regression_heterogeneity"

* outputs:

** Table 2: Heterogeneous effects procurement contract awards on firm investment and employment.
** Table C3: Further heterogeneous effects procurement contract awards on firm investment and employment.

do "${path_work}/nuts_analysis"

*********************************************************
