* Author(s)    :  Ricardo Gabriel
* Date         :  07/10/2021
* Update       :  15/09/2022
* Description  :  Regression analysis with annual data
* Dependencies :  ${path_work}/Annual_Contest.dta
* Modifications:  Change background, remove one horizon
* Products     :  log files, png figures, latex files in results folder.

* NEW VERSION
* Modifications:  (25/03/2024, João Quelhas, creation of replication package)

*********************************************************
*                       Preamble                        *
*********************************************************

local color "white"
local scale = 1.75

*********************************************************
*                      Assumptions                      *
*********************************************************

** DATASET

* Upload Cover Sheet dataset and merge with the other ones.
use "${path_source}/CBHP_A_YFRM_20062021_JUN23_ROSTO_V01.dta", clear

merge m:m tina ano using "${path_source}/CBHP_A_YFRM_20062021_JUN23_CONTAS_V01.dta"
drop _merge
merge m:m tina ano using "${path_source}/CBHP_A_YFRM_20062021_JUN23_PESSOAL_V01.dta"
drop _merge
merge m:m tina ano using "${path_source}/CBHP_A_YFRM_20062021_JUN23_MG_V01.dta"
drop _merge

* Rename the variable year.
rename ano year

* Save the merged dataset.
save "${path_work}/nuts/CBHP_A.dta", replace

* Create a smaller dataset and save it with the following variables:
* tina - firm identifier
* year - year of the dataset
* B001 - total assets
* D053 - interest expenses
preserve
gen valueadded	= (D001 + D111) - (D025 + D026 + DL047)
keep tina year B001 D053 sitempresa E002 distrito valueadded
save "${path_work}/nuts/B001_A_NUTs.dta", replace
restore

* Upload CRC COVER dataset.
use "${path_source}/CRC_A_FRM_APR19_COVER_V01.dta", clear

* Identify duplicated firm identifiers (tina).
duplicates tag tina, gen(duplicates)
sort duplicates tina maxdate
gen drop = 0
replace drop = 1 if tina == tina[_n+1]

* Keep the latest observation of the duplicates identified.
drop if drop == 1
drop duplicates drop

* Save the dataset with unique firm identifiers.
save "${path_work}/nuts/Cover_Unique.dta", replace 

* Upload CRC COBR dataset from 2007.
* COBR = Firm Level Credit Outstanding & Bank Relationship File 
use "${path_source}/CRC_A_MFRM_2007_APR19_COBR_V01.dta", clear

* Merge with monthly data from 2008 to 2018.
forvalues x = 8/9 {
	append using "${path_source}/CRC_A_MFRM_200`x'_APR19_COBR_V01.dta"
}
forvalues x = 10/18 {
	append using "${path_source}/CRC_A_MFRM_20`x'_APR19_COBR_V01.dta"
}

* Check whether the sum of collateral is equal to the credit effectively borrowed.
noi: gen colateral = valor_g1 + valor_g2 + valor_g3 + valor_g4 +valor_g5 + valor_g6
noi: gen dif = valor_efectivo - colateral
noi: sum dif, d

* If dif > 0, it means that there are firms with unsecured creditvarlist
* In the dataset, d can be negative which means that firms provide more colateral than the borrowing amount.

* If a firm has more colateral than borrowing amount, set it to 0.
* It is a measurement error (data glitch) and should not be taken into account.
noi: gen nocolateral = valor_efectivo - colateral
noi: sum nocolateral, d
noi: replace nocolateral = 0 if nocolateral < 0
drop dif

* valor_g1 Credit secured by real collateral mortgaged
* valor_g2 Credit secured by real collateral not mortgaged
* valor_g3 Credit secured by financial collateral
* valor_g4 Credit secured by personal guarantee provided by firm or individual
* valor_g5 Credit secured by personal guarantee granted by the state or financial institution
* valor_g6 Credit secured by other guarantees

* Add to credit secured the value of the unsecured credit. 
gen valor_g4_ori = valor_g4 + nocolateral
gen valor_g6_ori = valor_g6 + nocolateral

* Set the panel with id(tina) t(month)
xtset tina date

* Save the dataset.
save "${path_work}/nuts/Credit_M.dta", replace

* Collapse into annual data using the mean value over the year.
format date %10.0g
gen date_ = dofm(date)
gen year = year(date_)
drop date date_
order tina year
ds year tina, not
collapse (last) `r(varlist)', by(year tina)

* Set the panel with id(tina) t(year)
xtset tina year

* Save the dataset.
save "${path_work}/nuts/Credit_A.dta", replace

* Upload BASE dataset.
use "${path_source}/PM111_A_BASE_BPLIM.dta", clear

* Rename the firm identifier to tina.
rename adjudicatario_tina tina

* Adjust the date of the contract.
replace year = year - 1 if month == 1
replace month = 12 if month == 1
replace month = month - 1 if month != 1

* Summarize the variable procedimento (procedures)
noi: sum procedimento

* Keep public contests.
noi: keep if inrange(procedimento,5,7)

* Keep positive awards.
noi: keep if preco > 0

* Keep contests with solely one winner.
noi: keep if number_adjudicatarios == 1

* keep needed variables.
noi: keep tina year month preco prazo local number_concorrentes date_fecho preco_total adjudicante_type

* Collapse monthly awards, computing the sum of awards and the mean of days to deadline. 
collapse (sum) preco (mean) prazo, by(year month tina)

* Summarize the variable preco (awards).
noi: sum preco, d

* Create a variable date with year and month and format it.
gen date = ym(year,month)
format date %tm

* Rename the variable preco as award.
rename preco award
label variable award "Monthly aggregate of procurement revenues announced"

* Set the panel with the firm identifier and the date (year, month).
xtset tina date

* Save the dataset.
save "${path_work}/nuts/Procurement_Contest_M.dta", replace

** Save the annual version of the dataset.

* Replace prazo if it is more than 10 years.
replace prazo = 3650 if prazo > 3650

* Collapse yearly awards, computing the sum of awards and the mean of days to deadline. 
collapse (sum) award (mean) prazo, by(year tina)
label variable award "Annual aggregate of procurement revenues announced"

* Summarize the variable award.
noi: sum award, d

* Set the panel with the firm identifier and the date (year)
xtset tina year

* Save the dataset.
save "${path_work}/nuts/Procurement_Contest_A.dta", replace


* Merge annual procurement data with credit data (main dataset).

*** Prepare dataset for matching design exercise ***
* Collect all dependent variables needed.

* Load the dataset "Credit_A.dta"
use "${path_work}/nuts/Credit_A.dta", clear

* Merge the dataset "Procurement_Contest_A.dta" with the previous dataset
merge m:m tina year using "${path_work}/nuts/Procurement_Contest_A.dta"

* Keep observations only for the years between 2007 and 2019
drop if year < 2007 | year > 2019

* Drop observations where the merge failed
drop if _merge == 2

* Drop the _merge variable
drop _merge

* Merge the dataset "B001_A_NUTs.dta" with the previous dataset
merge m:m tina year using "${path_work}/nuts/B001_A_NUTs.dta"

* Drop observations where the merge failed
drop if _merge == 2

* Drop the _merge variable
drop _merge

* Merge the dataset "Cover_Unique.dta" with the previous dataset
merge m:m tina using "${path_work}/nuts/Cover_Unique.dta"

* Drop observations where the merge failed
drop if _merge == 2

* Drop the _merge variable
drop _merge

* Order the dataset by "tina", "year", and "award"
order tina year award

* Replace missing values in "award" with 0
replace award = 0 if missing(award)

* Declare the dataset as a panel dataset
xtset tina year

* Save the dataset
save "${path_work}/nuts/Yearly_Contest.dta", replace

* Load the previously saved dataset
use "${path_work}/nuts/Yearly_Contest.dta", clear

* Preserve the dataset in its current state
preserve

* Collapse the dataset to calculate the sum of "award" by "tina"
collapse (sum) award, by(tina)

* Keep observations where the sum of "award" is greater than 0
keep if award > 0

* Drop the "award" variable
drop award

* Save the collapsed dataset
save "${path_work}/nuts/collapsed_yearly", replace

* Restore the dataset to its previous state
restore

* Load the collapsed dataset
use "${path_work}/nuts/Yearly_Contest.dta", clear

* Merge the collapsed dataset with the previously saved collapsed dataset
merge m:1 tina using "${path_work}/nuts/collapsed_yearly.dta"

* Keep observations where the merge was successful
keep if _merge == 3

* Drop the _merge variable
drop _merge

* Save the dataset
save "${path_work}/nuts/Yearly_Contest_award", replace

* Load the dataset "coconuts_final.dta"
use "${path_tools}/coconuts_final.dta", clear

* Drop observations where "nuts3_v2013" is equal to 1.
drop if nuts3_v2013 == 1

* Decode the "__conc__" variable to generate a new variable "st".
decode __conc__, gen(st)

* Adjust "st" values based on specific conditions.
replace st = st + "_RAA" if __conc__ == 4201 | __conc__ == 4501

* Generate a new variable "municipality" from "st".
gen municipality = substr(st, 8, .)

* Generate a unique identifier variable "id".
egen id = group(municipality)

* Decode the "nuts3_v2013" variable to generate a new variable "nu".
decode nuts3_v2013, gen(nu)

* Generate a new variable "Nuts" combining "PT" with the first three characters of "nu".
gen Nuts = "PT" + substr(nu, 1, 3)

* Keep only relevant variables.
keep id municipality Nuts

* Save the dataset.
save "${path_work}/nuts/Nuts.dta", replace

* Load the dataset "Yearly_Contest.dta".
use "${path_work}/nuts/Yearly_Contest.dta", clear

* Replace specific values in "municipality".
replace municipality = 999999999 if municipality == -99999998

* Decode "municipality" to generate a new variable "name".
decode municipality, gen(name)

* Adjust "name" values based on specific conditions.
replace name = name + "_RAA" if municipality == 310000280 | municipality == 310000291

* Generate a new variable "mun" from "name".
gen mun = substr(name, 11, .)

* Drop the old "municipality" variable.
drop municipality

* Generate a new "municipality" variable from "name".
gen municipality = substr(name, 11, .)

* Standardize municipality names.
replace municipality = "Alfândega da Fé" if municipality == "Alfandega da Fé"
replace municipality = "Alijó" if municipality == "Alijo"
replace municipality = "Bragança" if municipality == "Brangaça"
replace municipality = "Freixo de Espada à Cinta" if municipality == "Freixo de Espada a Cinta"
replace municipality = "Lourinhã" if municipality == "Lourinha"
replace municipality = "Lousã" if municipality == "Lousa"
replace municipality = "Mêda" if municipality == "Meda"
replace municipality = "Ponte de Sor" if municipality == "Ponte de Sôr"
replace municipality = "Porto de Mós" if municipality == "Porto de Mos"
replace municipality = "Póvoa de Lanhoso" if municipality == "Povoa de Lanhoso"
replace municipality = "Póvoa de Varzim" if municipality == "Povoa de Varzim"
replace municipality = "Santa Marta de Penaguião" if municipality == "Sta. Marta de Penaguião"
replace municipality = "Santiago do Cacém" if municipality == "Santiago do Cacem"
replace municipality = "São João da Madeira" if municipality == "São João de Madeira"
replace municipality = "São João da Pesqueira" if municipality == "São João de Pesqueira"
replace municipality = "Vila Franca do Campo" if municipality == "Vila Franca de Campo"
replace municipality = "Vila Velha de Ródão" if municipality == "Vila Velha de Rodão"
replace municipality = "Vila da Praia da Vitória" if municipality == "Vila Praia da Vitoria"

* Merge with "Nuts.dta" to get NUTS codes.
noi: merge m:1 municipality using "${path_work}/nuts/Nuts.dta" 

* Drop observations where the merge failed.
drop if _merge != 3

* Drop unnecessary variables.
drop _merge

* Drop observations where "id" is missing.
drop if missing(id)

* Generate a variable "winner".
gen winner = 1 if award != 0
replace winner = 0 if winner == .

if ${replication} == 1 {
	
	rename valor_global_p    valor_global
	rename valor_efectivo_p  valor_efectivo
	rename valor_potencial_p valor_potencial
	rename valor_vencido_p   valor_vencido
	rename valor_curto_o_p   valor_curto_o
	rename valor_longo_o_p   valor_longo_o
	rename valor_curto_r_p   valor_curto_r
	rename valor_longo_r_p   valor_longo_r
	
	rename valor_g1_p valor_g1
	rename valor_g2_p valor_g2
	rename valor_g3_p valor_g3
	rename valor_g4_p valor_g4
	rename valor_g5_p valor_g5
	rename valor_g6_p valor_g6

	rename valor_prazo1_r_p valor_prazo1_r
	rename valor_prazo2_r_p valor_prazo2_r
	rename valor_prazo3_r_p valor_prazo3_r
	rename valor_prazo4_r_p valor_prazo4_r
	rename valor_prazo5_r_p valor_prazo5_r
	
	rename valor_prazo1_o_p valor_prazo1_o
	rename valor_prazo2_o_p valor_prazo2_o
	rename valor_prazo3_o_p valor_prazo3_o
	rename valor_prazo4_o_p valor_prazo4_o
	rename valor_prazo5_o_p valor_prazo5_o

}

* Collapse the dataset to calculate sums by "year", "Nuts", and "winner".
collapse (sum) valor_g4 nocolateral valor_efectivo value

*********************************************************
