* Author(s)    :  Ricardo Gabriel
* Date         :  07/10/2021
* Update       :  15/09/2022
* Description  :  Regression analysis with annual data
* Dependencies :  ${path_work}/Annual_Contest.dta
* Modifications:  Change background, remove one horizon
* Products     :  log files, pdf figures, latex files in results folder.

* NEW VERSION
* Modifications:  (25/03/2024, João Quelhas, creation of replication package)

*********************************************************
*                      Graphs Style                     *
*********************************************************

grstyle init
grstyle set plain, nogrid box noextend
grstyle yesno draw_major_vgrid yes
grstyle graphsize x 12
grstyle graphsize y 6
grstyle color background white

*********************************************************
*                       Preamble                        *
*********************************************************

local color "white"
local scale = 2

*********************************************************
*              Local Projections Analysis               *
*********************************************************

use "${path_work}/auxiliary/annual_analysis_intensive.dta", clear

********************
*    Preamble      *
********************

* Generate variabel sample - important for matching samples.
gen sample = 1

* Define the number of years for the horizon estimation.
local horizon = 2
local mh = -3

* Define the number of lags for control variables.
local lags = 1

* Define the key independent variables.
local rhsvarlist award

* Define the list of credit variables to be analyzed (these are % of total assets)
local creditvarlist valor_global valor_efectivo valor_potencial cash ncassets ppe intangibles fin_inv turnover COGS EBITDA income

local creditvarlist1 valor_efectivo // variable for Figure 1

local creditvarlist3 valor_potencial cash // variables for Figure 3

local creditvarlist6 ncassets ppe intangibles fin_inv turnover COGS EBITDA income // variables for Figure 6 

local creditvarlistc2 valor_global valor_efectivo valor_potencial cash // variables for Table C2

* Define the list of balance sheet variables to be analyzed.
local balancevarlist employees valueadded // variables for Figure 6 

// NOT USED: totalhours wagepw  

* Define full list of variables to use as lhsvar.
local allvarlist interest `creditvarlist' `balancevarlist' // variables for Figure 2

// NOT USED: interest2 interest3

********************
* Data preparation *
********************

* Compute forward change of balance sheet variables as growth rate relative to period t-1.
foreach lhsvar in `balancevarlist' {
	
	forvalues i = `mh'(1)`horizon' {
		
		if (`i'<0){
		
		local ii = `i' + abs(`mh')
		local ll = abs(`i')
		
			gen F`ii'`lhsvar' = (L`ll'.`lhsvar' - L.`lhsvar') / L.`lhsvar'*100
		}
		
		else {
		
		local ii = `i' + abs(`mh')
		
			gen F`ii'`lhsvar' = (F`i'.`lhsvar' - L.`lhsvar') / L.`lhsvar'*100
		}
	}
}

* Compute forward change of credit variables as growth rate relative to period t-1.
foreach lhsvar in `creditvarlist' {
	
	forvalues i =  `mh'(1)`horizon' {
		
		if (`i' < 0){
		
		local ii = `i' + abs(`mh')
		local ll = abs(`i')
		
			gen F`ii'`lhsvar' = (L`ll'.`lhsvar' - L.`lhsvar') / L.B001*100
		}
	
		else {
	
		local ii = `i' + abs(`mh')
			
			gen F`ii'`lhsvar' = (F`i'.`lhsvar' - L.`lhsvar') / L.B001*100
		}
	}
}

* Compute forward change of interest variables as the difference relative to period t-1.
foreach lhsvar in interest {
	
	forvalues i =  `mh'(1)`horizon' {
		
		if (`i' < 0){
		
		local ii = `i' + abs(`mh')
		local ll = abs(`i')
		
			gen F`ii'`lhsvar'  = (L`ll'.`lhsvar'  - L.`lhsvar' )
		}
    
		else {
		
		local ii = `i' + abs(`mh')
			
			gen F`ii'`lhsvar'  = (F`i'.`lhsvar'  - L.`lhsvar' )
		}
	}
}

* Define list of control variables.
foreach lhsvar in `allvarlist' {
	
	foreach rhsvar in `rhsvarlist' {
    
	local controls`lhsvar'`rhsvar' l(1/`lags').`rhsvar' l(1/`lags').`lhsvar'
	
	}
}

* Storing variables.
foreach lhsvar in `allvarlist' {
	
	foreach rhsvar in `rhsvarlist' {
	
	    cap gen b_`lhsvar'_`rhsvar' = .
	    cap gen se_`lhsvar'_`rhsvar' = .
	    cap gen up1_`lhsvar'_`rhsvar' = .
	    cap gen up2_`lhsvar'_`rhsvar' = .
	    cap gen dn1_`lhsvar'_`rhsvar' = .
	    cap gen dn2_`lhsvar'_`rhsvar' = .
	}
}

***********************
* Regression Analysis *
***********************

* CREDIT VARIABLES - OWN GROWTH

* Define local to start iteration as 0.
local iteration = 0

foreach lhsvar in `creditvarlist1' {

	local iteration = `iteration' + 1
  
	foreach rhsvar in `rhsvarlist' {
  
		forvalues match = 0(1)0 {
  
		* Match sample.
		if (`match' == 1){
		
		reghdfe F5`lhsvar' `rhsvar' `controls`lhsvar'`rhsvar'', absorb(tina t_i_FE)
		
		replace sample = e(sample)
		
		}
  
		if (`match' == 0){
		
		replace sample = 1
			
		}

		forvalues i = `mh'(1)`horizon' {
    
		local ii = `i' + abs(`mh')
    
		* Run local projections.
		reghdfe F`ii'`lhsvar' `rhsvar' `controls`lhsvar'`rhsvar'' if sample == 1 & award >0 & award <50, absorb(tina t_i_FE) vce(cluster tina)
    
		* Store results.
		eststo reg_`iteration'_`match'_`rhsvar'_`ii'
		replace b_`lhsvar'_`rhsvar'	= _b[`rhsvar'] if _n == `ii'+1
		replace se_`lhsvar'_`rhsvar' = _se[`rhsvar'] if _n == `ii'+1
		   
	}
   
	* Store the table in a tex file.
	esttab reg_`iteration'_`match'_`rhsvar'_* using "${path_results}/figures/figure_1/Table_`lhsvar'_`rhsvar'_`match'.tex", replace se sca(N) nonum b(2) se(2) sfmt(0) obslast star(* 0.10 ** 0.05 *** 0.01)
	esttab reg_`iteration'_`match'_`rhsvar'_* using "${path_results}/tables/Table_2/Table_`lhsvar'_`rhsvar'_`match'.tex", replace se sca(N) nonum b(2) se(2) sfmt(0) obslast star(* 0.10 ** 0.05 *** 0.01)
	eststo clear
  
	* Produce graphs.
	cap gen periods = _n - 1 + `mh' if _n <= (`horizon' + abs(`mh')+1)
	cap gen zero = 0 if _n <= (`horizon' + abs(`mh')+1)
  
	* Compute confidence bands.
	scalar sig1 = 0.05
	scalar sig2 = 0.10
	replace up1_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' + invnormal(1-sig1/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
	replace up2_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' + invnormal(1-sig2/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
	replace dn1_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' - invnormal(1-sig1/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
	replace dn2_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' - invnormal(1-sig2/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
  
  
  if ("`lhsvar'" == "valor_g1" | "`lhsvar'" == "valor_g2" | "`lhsvar'" == "valor_g3" | "`lhsvar'" == "valor_g4" | "`lhsvar'" == "valor_g5" | "`lhsvar'" == "valor_g6" | "`lhsvar'" == "valor_g4_ori" | "`lhsvar'" == "valor_g6_ori" | "`lhsvar'" == "nocolateral" | "`lhsvar'" == "collateral" ) {
	
	* Graphs with collateral.
	twoway (rcap up1_`lhsvar'_`rhsvar' dn1_`lhsvar'_`rhsvar' periods, lcolor(gs13)) (rcap up2_`lhsvar'_`rhsvar' dn2_`lhsvar'_`rhsvar' periods, lcolor(dkorange)) (scatter b_`lhsvar'_`rhsvar' periods, msymbol(D) msize(medlarge) mcolor(orange)) (line zero periods, lcolor(black)), ylabel(-2(2)6) scale(`scale') ytitle("Growth (% of total assets)") xtitle("Year to Event") graphregion(fcolor(`color')) plotregion(color(`color')) name(`lhsvar'_`rhsvar'_`horizon', replace) legend(off) xlabel(`mh'(1)`horizon')
	
	* Export graph.
	graph export "${path_results}/figures/figure_1/Figure_`lhsvar'_`rhsvar'_y_`match'.pdf", as(pdf) replace
	window manage close graph
	
	}
	else{
 
	* Graphs for the other variables.
	twoway (rcap up1_`lhsvar'_`rhsvar' dn1_`lhsvar'_`rhsvar' periods, lcolor(gs13)) (rcap up2_`lhsvar'_`rhsvar' dn2_`lhsvar'_`rhsvar' periods, lcolor(dkorange)) (scatter b_`lhsvar'_`rhsvar' periods, msymbol(D) msize(medlarge) mcolor(orange)) (line zero periods, lcolor(black)), scale(`scale') ytitle("Growth (% of total assets)") xtitle("Year to Event") graphregion(fcolor(`color')) plotregion(color(`color')) name(`lhsvar'_`rhsvar'_`horizon', replace) legend(off) xlabel(`mh'(1)`horizon')
  	
	* Export graph.
	graph export "${path_results}/figures/figure_1/Figure_`lhsvar'_`rhsvar'_y_`match'.pdf", as(pdf) replace
	window manage close graph
	
	}
	}
	}
}





* CREDIT VARIABLES - OWN GROWTH

* Define local to start iteration as 0.
local iteration = 0

foreach lhsvar in `creditvarlist3' {

	local iteration = `iteration' + 1
  
	foreach rhsvar in `rhsvarlist' {
  
		forvalues match = 0(1)0 {
  
		* Match sample.
		if (`match' == 1){
		
		reghdfe F5`lhsvar' `rhsvar' `controls`lhsvar'`rhsvar'', absorb(tina t_i_FE)
		
		replace sample = e(sample)
		
		}
  
		if (`match' == 0){
		
		replace sample = 1
			
		}

		forvalues i = `mh'(1)`horizon' {
    
		local ii = `i' + abs(`mh')
    
		* Run local projections.
		reghdfe F`ii'`lhsvar' `rhsvar' `controls`lhsvar'`rhsvar'' if sample == 1 & award >0 & award <50, absorb(tina t_i_FE) vce(cluster tina)
    
		* Store results.
		eststo reg_`iteration'_`match'_`rhsvar'_`ii'
		replace b_`lhsvar'_`rhsvar'	= _b[`rhsvar'] if _n == `ii'+1
		replace se_`lhsvar'_`rhsvar' = _se[`rhsvar'] if _n == `ii'+1
		   
	}
   
	* Store the table in a tex file.
	esttab reg_`iteration'_`match'_`rhsvar'_* using "${path_results}/figures/figure_3/Table_`lhsvar'_`rhsvar'_`match'.tex", replace se sca(N) nonum b(2) se(2) sfmt(0) obslast star(* 0.10 ** 0.05 *** 0.01)
	eststo clear
  
	* Produce graphs.
	cap gen periods = _n - 1 + `mh' if _n <= (`horizon' + abs(`mh')+1)
	cap gen zero = 0 if _n <= (`horizon' + abs(`mh')+1)
  
	* Compute confidence bands.
	scalar sig1 = 0.05
	scalar sig2 = 0.10
	replace up1_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' + invnormal(1-sig1/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
	replace up2_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' + invnormal(1-sig2/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
	replace dn1_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' - invnormal(1-sig1/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
	replace dn2_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' - invnormal(1-sig2/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
  
  
  if ("`lhsvar'" == "valor_g1" | "`lhsvar'" == "valor_g2" | "`lhsvar'" == "valor_g3" | "`lhsvar'" == "valor_g4" | "`lhsvar'" == "valor_g5" | "`lhsvar'" == "valor_g6" | "`lhsvar'" == "valor_g4_ori" | "`lhsvar'" == "valor_g6_ori" | "`lhsvar'" == "nocolateral" | "`lhsvar'" == "collateral" ) {
	
	* Graphs with collateral.
	twoway (rcap up1_`lhsvar'_`rhsvar' dn1_`lhsvar'_`rhsvar' periods, lcolor(gs13)) (rcap up2_`lhsvar'_`rhsvar' dn2_`lhsvar'_`rhsvar' periods, lcolor(dkorange)) (scatter b_`lhsvar'_`rhsvar' periods, msymbol(D) msize(medlarge) mcolor(orange)) (line zero periods, lcolor(black)), ylabel(-2(2)6) scale(`scale') ytitle("Growth (% of total assets)") xtitle("Year to Event") graphregion(fcolor(`color')) plotregion(color(`color')) name(`lhsvar'_`rhsvar'_`horizon', replace) legend(off) xlabel(`mh'(1)`horizon')
	
	* Export graph.
	graph export "${path_results}/figures/figure_3/Figure_`lhsvar'_`rhsvar'_y_`match'.pdf", as(pdf) replace
	window manage close graph
	
	}
	else{
 
	* Graphs for the other variables.
	twoway (rcap up1_`lhsvar'_`rhsvar' dn1_`lhsvar'_`rhsvar' periods, lcolor(gs13)) (rcap up2_`lhsvar'_`rhsvar' dn2_`lhsvar'_`rhsvar' periods, lcolor(dkorange)) (scatter b_`lhsvar'_`rhsvar' periods, msymbol(D) msize(medlarge) mcolor(orange)) (line zero periods, lcolor(black)), scale(`scale') ytitle("Growth (% of total assets)") xtitle("Year to Event") graphregion(fcolor(`color')) plotregion(color(`color')) name(`lhsvar'_`rhsvar'_`horizon', replace) legend(off) xlabel(`mh'(1)`horizon')
  	
	* Export graph.
	graph export "${path_results}/figures/figure_3/Figure_`lhsvar'_`rhsvar'_y_`match'.pdf", as(pdf) replace
	window manage close graph
	
	}
	}
	}
}

* CREDIT VARIABLES - OWN GROWTH

* Define local to start iteration as 0.
local iteration = 0

foreach lhsvar in `creditvarlist6' {

	local iteration = `iteration' + 1
  
	foreach rhsvar in `rhsvarlist' {
  
		forvalues match = 0(1)0 {
  
		* Match sample.
		if (`match' == 1){
		
		reghdfe F5`lhsvar' `rhsvar' `controls`lhsvar'`rhsvar'', absorb(tina t_i_FE)
		
		replace sample = e(sample)
		
		}
  
		if (`match' == 0){
		
		replace sample = 1
			
		}

		forvalues i = `mh'(1)`horizon' {
    
		local ii = `i' + abs(`mh')
    
		* Run local projections.
		reghdfe F`ii'`lhsvar' `rhsvar' `controls`lhsvar'`rhsvar'' if sample == 1 & award >0 & award <50, absorb(tina t_i_FE) vce(cluster tina)
    
		* Store results.
		eststo reg_`iteration'_`match'_`rhsvar'_`ii'
		replace b_`lhsvar'_`rhsvar'	= _b[`rhsvar'] if _n == `ii'+1
		replace se_`lhsvar'_`rhsvar' = _se[`rhsvar'] if _n == `ii'+1
		   
	}
   
	* Store the table in a tex file.
	esttab reg_`iteration'_`match'_`rhsvar'_* using "${path_results}/figures/figure_6/Table_`lhsvar'_`rhsvar'_`match'.tex", replace se sca(N) nonum b(2) se(2) sfmt(0) obslast star(* 0.10 ** 0.05 *** 0.01)

  if ("`lhsvar'" == "ncassets") {
	
	esttab reg_`iteration'_`match'_`rhsvar'_* using "${path_results}/tables/Table_2/Table_`lhsvar'_`rhsvar'_`match'.tex", replace se sca(N) nonum b(2) se(2) sfmt(0) obslast star(* 0.10 ** 0.05 *** 0.01)
	
	}
	
	eststo clear
  
	* Produce graphs.
	cap gen periods = _n - 1 + `mh' if _n <= (`horizon' + abs(`mh')+1)
	cap gen zero = 0 if _n <= (`horizon' + abs(`mh')+1)
  
	* Compute confidence bands.
	scalar sig1 = 0.05
	scalar sig2 = 0.10
	replace up1_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' + invnormal(1-sig1/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
	replace up2_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' + invnormal(1-sig2/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
	replace dn1_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' - invnormal(1-sig1/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
	replace dn2_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' - invnormal(1-sig2/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
  
  
  if ("`lhsvar'" == "valor_g1" | "`lhsvar'" == "valor_g2" | "`lhsvar'" == "valor_g3" | "`lhsvar'" == "valor_g4" | "`lhsvar'" == "valor_g5" | "`lhsvar'" == "valor_g6" | "`lhsvar'" == "valor_g4_ori" | "`lhsvar'" == "valor_g6_ori" | "`lhsvar'" == "nocolateral" | "`lhsvar'" == "collateral" ) {
	
	* Graphs with collateral.
	twoway (rcap up1_`lhsvar'_`rhsvar' dn1_`lhsvar'_`rhsvar' periods, lcolor(gs13)) (rcap up2_`lhsvar'_`rhsvar' dn2_`lhsvar'_`rhsvar' periods, lcolor(dkorange)) (scatter b_`lhsvar'_`rhsvar' periods, msymbol(D) msize(medlarge) mcolor(orange)) (line zero periods, lcolor(black)), ylabel(-2(2)6) scale(`scale') ytitle("Growth (% of total assets)") xtitle("Year to Event") graphregion(fcolor(`color')) plotregion(color(`color')) name(`lhsvar'_`rhsvar'_`horizon', replace) legend(off) xlabel(`mh'(1)`horizon')
	
	* Export graph.
	graph export "${path_results}/figures/figure_6/Figure_`lhsvar'_`rhsvar'_y_`match'.pdf", as(pdf) replace
	window manage close graph
	
	}
	else{
 
	* Graphs for the other variables.
	twoway (rcap up1_`lhsvar'_`rhsvar' dn1_`lhsvar'_`rhsvar' periods, lcolor(gs13)) (rcap up2_`lhsvar'_`rhsvar' dn2_`lhsvar'_`rhsvar' periods, lcolor(dkorange)) (scatter b_`lhsvar'_`rhsvar' periods, msymbol(D) msize(medlarge) mcolor(orange)) (line zero periods, lcolor(black)), scale(`scale') ytitle("Growth (% of total assets)") xtitle("Year to Event") graphregion(fcolor(`color')) plotregion(color(`color')) name(`lhsvar'_`rhsvar'_`horizon', replace) legend(off) xlabel(`mh'(1)`horizon')
  	
	* Export graph.s
	graph export "${path_results}/figures/figure_6/Figure_`lhsvar'_`rhsvar'_y_`match'.pdf", as(pdf) replace
	window manage close graph
	
	}
	}
	}
}


* CREDIT VARIABLES - OWN GROWTH

* Define local to start iteration as 0.
local iteration = 0

foreach lhsvar in `creditvarlistc2' {

	local iteration = `iteration' + 1
  
	foreach rhsvar in `rhsvarlist' {
  
		forvalues match = 0(1)0 {
  
		* Match sample.
		if (`match' == 1){
		
		reghdfe F5`lhsvar' `rhsvar' `controls`lhsvar'`rhsvar'', absorb(tina t_i_FE)
		
		replace sample = e(sample)
		
		}
  
		if (`match' == 0){
		
		replace sample = 1
			
		}

		forvalues i = `mh'(1)`horizon' {
    
		local ii = `i' + abs(`mh')
    
		* Run local projections.
		reghdfe F`ii'`lhsvar' `rhsvar' `controls`lhsvar'`rhsvar'' if sample == 1 & award >0 & award <50, absorb(tina t_i_FE) vce(cluster tina)
    
		* Store results.
		eststo reg_`iteration'_`match'_`rhsvar'_`ii'
		replace b_`lhsvar'_`rhsvar'	= _b[`rhsvar'] if _n == `ii'+1
		replace se_`lhsvar'_`rhsvar' = _se[`rhsvar'] if _n == `ii'+1
		   
	}
   
	* Store the table in a tex file.
	esttab reg_`iteration'_`match'_`rhsvar'_* using "${path_results}/tables/Table_C2/Table_`lhsvar'_`rhsvar'_`match'.tex", replace se sca(N) nonum b(2) se(2) sfmt(0) obslast star(* 0.10 ** 0.05 *** 0.01)
	eststo clear
  
	* Produce graphs.
	cap gen periods = _n - 1 + `mh' if _n <= (`horizon' + abs(`mh')+1)
	cap gen zero = 0 if _n <= (`horizon' + abs(`mh')+1)
  
	* Compute confidence bands.
	scalar sig1 = 0.05
	scalar sig2 = 0.10
	replace up1_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' + invnormal(1-sig1/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
	replace up2_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' + invnormal(1-sig2/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
	replace dn1_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' - invnormal(1-sig1/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
	replace dn2_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' - invnormal(1-sig2/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
  
  
  if ("`lhsvar'" == "valor_g1" | "`lhsvar'" == "valor_g2" | "`lhsvar'" == "valor_g3" | "`lhsvar'" == "valor_g4" | "`lhsvar'" == "valor_g5" | "`lhsvar'" == "valor_g6" | "`lhsvar'" == "valor_g4_ori" | "`lhsvar'" == "valor_g6_ori" | "`lhsvar'" == "nocolateral" | "`lhsvar'" == "collateral" ) {
	
	* Graphs with collateral.
	twoway (rcap up1_`lhsvar'_`rhsvar' dn1_`lhsvar'_`rhsvar' periods, lcolor(gs13)) (rcap up2_`lhsvar'_`rhsvar' dn2_`lhsvar'_`rhsvar' periods, lcolor(dkorange)) (scatter b_`lhsvar'_`rhsvar' periods, msymbol(D) msize(medlarge) mcolor(orange)) (line zero periods, lcolor(black)), ylabel(-2(2)6) scale(`scale') ytitle("Growth (% of total assets)") xtitle("Year to Event") graphregion(fcolor(`color')) plotregion(color(`color')) name(`lhsvar'_`rhsvar'_`horizon', replace) legend(off) xlabel(`mh'(1)`horizon')
		
	}
	else{
 
	* Graphs for the other variables.
	twoway (rcap up1_`lhsvar'_`rhsvar' dn1_`lhsvar'_`rhsvar' periods, lcolor(gs13)) (rcap up2_`lhsvar'_`rhsvar' dn2_`lhsvar'_`rhsvar' periods, lcolor(dkorange)) (scatter b_`lhsvar'_`rhsvar' periods, msymbol(D) msize(medlarge) mcolor(orange)) (line zero periods, lcolor(black)), scale(`scale') ytitle("Growth (% of total assets)") xtitle("Year to Event") graphregion(fcolor(`color')) plotregion(color(`color')) name(`lhsvar'_`rhsvar'_`horizon', replace) legend(off) xlabel(`mh'(1)`horizon')
  		
	}
	}
	}
}


* BALANCE SHEET VARIABLES - OWN GROWTH

* Define local to start iteration as 0.
local iteration = 0

foreach lhsvar in `balancevarlist' {
	
	local iteration = `iteration' + 1
	
	foreach rhsvar in `rhsvarlist' {
	
	forvalues match = 0(1)0 {
	
	* Match sample.
	if (`match' == 1){
    
		noi: reghdfe F5`lhsvar' `rhsvar' `controls`lhsvar'`rhsvar'', absorb(tina t_i_FE)
		noi: replace sample = e(sample)
	}
	
	if (`match' == 0){
    
		replace sample = 1
	}

	forvalues i = `mh'(1)`horizon' {
    
	local ii = `i' + abs(`mh')
    
	* Run local projections.
	reghdfe F`ii'`lhsvar' `rhsvar' `controls`lhsvar'`rhsvar'' if sample==1 & award >0 & award <50, absorb(tina t_i_FE) vce(cluster tina)
    
	* Store results.
	eststo reg_`iteration'_`match'_`rhsvar'_`ii'
	replace b_`lhsvar'_`rhsvar'	= _b[`rhsvar'] if _n == `ii'+1
	replace se_`lhsvar'_`rhsvar' = _se[`rhsvar'] if _n == `ii'+1
  
	}
   
	* Store the table in a tex file.
	esttab reg_`iteration'_`match'_`rhsvar'_* using "${path_results}/figures/figure_6/Table_`lhsvar'_`rhsvar'_`match'.tex", replace se sca(N) nonum b(2) se(2) sfmt(0) obslast star(* 0.10 ** 0.05 *** 0.01)

	if ("`lhsvar'" == "employees") {
	
	esttab reg_`iteration'_`match'_`rhsvar'_* using "${path_results}/tables/Table_2/Table_`lhsvar'_`rhsvar'_`match'.tex", replace se sca(N) nonum b(2) se(2) sfmt(0) obslast star(* 0.10 ** 0.05 *** 0.01)
	
	}

	eststo clear
  
	* Produce graphs.
	cap gen periods = _n - 1 + `mh' if _n <= (`horizon' + abs(`mh')+1)
	cap gen zero = 0 if _n <= (`horizon' + abs(`mh')+1)
  
	* Compute confidence bands.
	scalar sig1 = 0.05
	scalar sig2 = 0.10
	replace up1_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' + invnormal(1-sig1/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
	replace up2_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' + invnormal(1-sig2/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
	replace dn1_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' - invnormal(1-sig1/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
	replace dn2_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' - invnormal(1-sig2/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
  
	* Graphs for all variables.
	twoway (rcap up1_`lhsvar'_`rhsvar' dn1_`lhsvar'_`rhsvar' periods, lcolor(gs13)) (rcap up2_`lhsvar'_`rhsvar' dn2_`lhsvar'_`rhsvar' periods, lcolor(dkorange)) (scatter b_`lhsvar'_`rhsvar' periods, msymbol(D) msize(medlarge) mcolor(orange)) (line zero periods, lcolor(black)), scale(`scale') ytitle("Growth (%)") xtitle("Year to Event") graphregion(fcolor(`color')) plotregion(color(`color')) name(`lhsvar'_`rhsvar'_`horizon', replace) legend(off) xlabel(`mh'(1)`horizon')
  	
	* Export graph.
	graph export "${path_results}/figures/figure_6/Figure_`lhsvar'_`rhsvar'_y_`match'.pdf", as(pdf) replace
	window manage close graph
	
	}
	}
}


* INTEREST RATE VARIABLES - PP CHANGE

* Define local to start iteration as 0.
local iteration = 0

foreach lhsvar in interest {
	
	local iteration = `iteration' + 1
  
	foreach rhsvar in `rhsvarlist' {
  	
	local match = 0
  
	* Match sample.
	if (`match' == 1){
		
		noi: reghdfe F5`lhsvar' `rhsvar' `controls`lhsvar'`rhsvar'', absorb(tina t_i_FE)
		noi: replace sample = e(sample)
	
	}
  
	if (`match' == 0){
	
		replace sample = 1
  
	}

	forvalues i = `mh'(1)`horizon' {
    
	local ii = `i' + abs(`mh')
    
	* Run local projections.
	reghdfe F`ii'`lhsvar' `rhsvar' `controls`lhsvar'`rhsvar'' if sample==1 & award >0 & award <50, absorb(tina t_i_FE) vce(cluster tina)
    
    	* Store results.
	eststo reg_`iteration'_`match'_`rhsvar'_`ii'
	replace b_`lhsvar'_`rhsvar'	= _b[`rhsvar'] if _n == `ii'+1
	replace se_`lhsvar'_`rhsvar' = _se[`rhsvar'] if _n == `ii'+1
  
	}
   
	* Store the table in a tex file.
	esttab reg_`iteration'_`match'_`rhsvar'_* using "${path_results}/figures/figure_2/Table_`lhsvar'_`rhsvar'_`match'.tex", replace se sca(N) nonum b(2) se(2) sfmt(0) obslast star(* 0.10 ** 0.05 *** 0.01)
	esttab reg_`iteration'_`match'_`rhsvar'_* using "${path_results}/tables/Table_C2/Table_`lhsvar'_`rhsvar'_`match'.tex", replace se sca(N) nonum b(2) se(2) sfmt(0) obslast star(* 0.10 ** 0.05 *** 0.01)

	eststo clear
  
	* Produce graphs.
	cap gen periods = _n - 1 + `mh' if _n <= (`horizon' + abs(`mh')+1)
	cap gen zero = 0 if _n <= (`horizon' + abs(`mh')+1)
  
	* Compute confidence bands.
	scalar sig1 = 0.05
	scalar sig2 = 0.10
	replace up1_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' + invnormal(1-sig1/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
	replace up2_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' + invnormal(1-sig2/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
	replace dn1_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' - invnormal(1-sig1/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
	replace dn2_`lhsvar'_`rhsvar' = b_`lhsvar'_`rhsvar' - invnormal(1-sig2/2)*se_`lhsvar'_`rhsvar' if _n <= (`horizon'+ abs(`mh') + 1)
  
	* Graphs for all variables.
	twoway (rcap up1_`lhsvar'_`rhsvar' dn1_`lhsvar'_`rhsvar' periods, lcolor(gs13)) (rcap up2_`lhsvar'_`rhsvar' dn2_`lhsvar'_`rhsvar' periods, lcolor(dkorange)) (scatter b_`lhsvar'_`rhsvar' periods, msymbol(D) msize(medlarge) mcolor(orange)) (line zero periods, lcolor(black)), scale(`scale') ytitle("Percentage Points") xtitle("Year to Event") graphregion(fcolor(`color')) plotregion(color(`color')) name(`lhsvar'_`rhsvar'_`horizon', replace) legend(off) xlabel(`mh'(1)`horizon')

	* Export graph.
	graph export "${path_results}/figures/figure_2/Figure_`lhsvar'_`rhsvar'_y_`match'.pdf", as(pdf) replace
	window manage close graph
  }
  
}

*********************************************************
