* Author(s)    :  Ricardo Gabriel
* Date         :  07/10/2021
* Update       :  15/09/2022
* Description  :  Regression analysis (heterogeneity)
* Dependencies :  ${path_work}/Annual_Contest.dta
* Modifications:  Change background, remove one horizon
* Products     :  log files, pdf figures, latex files in results folder.

* NEW VERSION
* Modifications:  (25/03/2024, João Quelhas, creation of replication package)

*********************************************************
*                      Graphs Style                     *
*********************************************************

grstyle init
grstyle set plain, nogrid box noextend
grstyle yesno draw_major_vgrid yes
grstyle graphsize x 12
grstyle graphsize y 6
grstyle color background white

*********************************************************
*                       Preamble                        *
*********************************************************

local color "white"
local scale = 2

*********************************************************
*                Heterogeneity analysis                 *
*********************************************************

*********************************************************
** Table 2: Heterogeneous effects procurement contract  *
** awards on firm credit, investment and employment     *
*********************************************************

** State-Dependencies

forvalues alt = 1/1 {

global state = `alt'

use "${path_work}/auxiliary/annual_analysis_intensive.dta", clear

* Create dummy for award variable
gen winner = (award>0)

if ($state == 1) {
	local state	= "big"
	local low	= "small"
	local high	= "big"
	
	gen big 	= 0 if l.dimcomissao <=2
	replace big 	= 1 if l.dimcomissao >=3

	cap gen state	= big
}

** Analysis

********************
*    Preamble      *
********************

* number of years for the horizon
local horizon = 2
local mh = 0

* number of lags for control variables
local lags = 1

* key independent variable
local rhsvarlist award

* list of credit variables to be analyzed
local creditvarlist valor_efectivo ncassets

* list of balance sheet variables to be analyzed
local balancevarlist employees 

* define full list of variables to use as lhsvar
local allvarlist `creditvarlist' `balancevarlist'

*****************************
* Data preparation for IRFs *
*****************************

* compute forward change of credit variables as growth rate relative to period t-1
foreach lhsvar in `balancevarlist' {
  
  forvalues i = `mh'(1)`horizon' {
	
	if (`i'<0){
		local ii = `i' + abs(`mh')
		local ll = abs(`i')
		gen F`ii'`lhsvar' = (L`ll'.`lhsvar' - L.`lhsvar')/ L.`lhsvar'*100
	}
	
	else {
		local ii = `i' + abs(`mh')
		gen F`ii'`lhsvar' = (F`i'.`lhsvar' - L.`lhsvar')/ L.`lhsvar'*100
	}
  }
}

foreach lhsvar in `creditvarlist' {
  forvalues i =  `mh'(1)`horizon' {
    if (`i'<0){
	local ii = `i' + abs(`mh')
	local ll = abs(`i')
	gen F`ii'`lhsvar' = (L`ll'.`lhsvar' - L.`lhsvar')/ L.B001*100
	}
    else {
	local ii = `i' + abs(`mh')
	gen F`ii'`lhsvar' = (F`i'.`lhsvar' - L.`lhsvar')/ L.B001*100
	}
  }
}

* State dependent variables

* daward
foreach lhsvar in `rhsvarlist' {
	gen `lhsvar'_high = `lhsvar' * `state'
	gen `lhsvar'_low  = `lhsvar' * (1 - `state')
}

foreach lhsvar in `allvarlist' {
  forvalues i =  `mh'(1)`horizon' {
  	local ii = `i' + abs(`mh')
  	gen F`ii'`lhsvar'_high = F`ii'`lhsvar' * `state'
	gen F`ii'`lhsvar'_low  = F`ii'`lhsvar' * (1 - `state')
  }
}



* list of control variables (attention F2 is F(abs(`mh'))) !
foreach lhsvar in `allvarlist' {
    
    local controls`lhsvar'award l(1/`lags').award_low l(1/`lags').award_high l(1/`lags').F0`lhsvar'_low l(1/`lags').F0`lhsvar'_high
 
 }

* storing variables
foreach lhsvar in `allvarlist' {
  foreach rhsvar in `rhsvarlist' {
    cap gen b_`lhsvar'_`rhsvar'_low   = .
    cap gen se_`lhsvar'_`rhsvar'_low  = .
    cap gen b_`lhsvar'_`rhsvar'_high  = .
    cap gen se_`lhsvar'_`rhsvar'_high = .
  }
cap gen ptest_`lhsvar' = .
cap gen hacph_`lhsvar' = .
cap gen arph_`lhsvar'  = .
}

***********************
* Regression Analysis *
***********************
local iteration = 0

foreach lhsvar in `creditvarlist' {
local iteration = `iteration' + 1
  foreach rhsvar in `rhsvarlist' {
  
  forvalues i = `mh'(1)`horizon' {
    
    local ii = `i' + abs(`mh')
    
    * run local projections
    reghdfe F`ii'`lhsvar' `rhsvar'_low `rhsvar'_high  `controls`lhsvar'`rhsvar'' if award > 0 &  award < 50, absorb(tina t_i_FE) vce(cluster tina)
    
    * store results
    eststo reg_`iteration'_`rhsvar'_`ii'
    replace b_`lhsvar'_`rhsvar'_low	= _b[`rhsvar'_low]   if _n == `ii'+1
    replace se_`lhsvar'_`rhsvar'_low    = _se[`rhsvar'_low]  if _n == `ii'+1
    replace b_`lhsvar'_`rhsvar'_high	= _b[`rhsvar'_high]  if _n == `ii'+1
    replace se_`lhsvar'_`rhsvar'_high   = _se[`rhsvar'_high] if _n == `ii'+1
    
    * test for differences
    test `rhsvar'_low = `rhsvar'_high
    replace ptest_`lhsvar' = r(p) if _n == `i'+1
    
    return list
    local p_value = r(p)
    
    local excel_number = `i' + 2

    putexcel set "${path_results}/tables/Table_2/Table_`lhsvar'_`rhsvar'_`state'_hac.xlsx", modify
    putexcel B`excel_number' = (`p_value')
    putexcel close

    
  }
  
  * store table in a tex file
  esttab reg_`iteration'_`rhsvar'_* using "${path_results}/tables/Table_2/Table_`lhsvar'_`rhsvar'_`state'_y.tex", replace se sca(N) nonum b(2) se(2) sfmt(0) obslast star(* 0.10 ** 0.05 *** 0.01)
  eststo clear
  
  * produce graphs
  cap gen periods = _n - 1 + `mh' if _n <= (`horizon' + abs(`mh')+1)
  cap gen zero = 0 if _n <= (`horizon' + abs(`mh')+1)
  
  * confidence bands
  scalar sig1 = 0.05
  scalar sig2 = 0.10
  
  cap gen up1_`lhsvar'_`rhsvar'_low = b_`lhsvar'_`rhsvar'_low + invnormal(1-sig1/2)*se_`lhsvar'_`rhsvar'_low if _n <= (`horizon'+ abs(`mh') + 1)
  cap gen up2_`lhsvar'_`rhsvar'_low = b_`lhsvar'_`rhsvar'_low + invnormal(1-sig2/2)*se_`lhsvar'_`rhsvar'_low if _n <= (`horizon'+ abs(`mh') + 1)
  cap gen dn1_`lhsvar'_`rhsvar'_low = b_`lhsvar'_`rhsvar'_low - invnormal(1-sig1/2)*se_`lhsvar'_`rhsvar'_low if _n <= (`horizon'+ abs(`mh') + 1)
  cap gen dn2_`lhsvar'_`rhsvar'_low = b_`lhsvar'_`rhsvar'_low - invnormal(1-sig2/2)*se_`lhsvar'_`rhsvar'_low if _n <= (`horizon'+ abs(`mh') + 1)
  
  
  cap gen up1_`lhsvar'_`rhsvar'_high = b_`lhsvar'_`rhsvar'_high + invnormal(1-sig1/2)*se_`lhsvar'_`rhsvar'_high if _n <= (`horizon'+ abs(`mh') + 1)
  cap gen up2_`lhsvar'_`rhsvar'_high = b_`lhsvar'_`rhsvar'_high + invnormal(1-sig2/2)*se_`lhsvar'_`rhsvar'_high if _n <= (`horizon'+ abs(`mh') + 1)
  cap gen dn1_`lhsvar'_`rhsvar'_high = b_`lhsvar'_`rhsvar'_high - invnormal(1-sig1/2)*se_`lhsvar'_`rhsvar'_high if _n <= (`horizon'+ abs(`mh') + 1)
  cap gen dn2_`lhsvar'_`rhsvar'_high = b_`lhsvar'_`rhsvar'_high - invnormal(1-sig2/2)*se_`lhsvar'_`rhsvar'_high if _n <= (`horizon'+ abs(`mh') + 1)
  
  }
}

* BALANCE SHEET VARIABLES - OWN GROWTH

local iteration = 0

foreach lhsvar in `balancevarlist' {
	
local iteration = `iteration' + 1
  
  foreach rhsvar in `rhsvarlist' {
  
  forvalues i = `mh'(1)`horizon' {
    
    local ii = `i' + abs(`mh')
    
    * run local projections
    reghdfe F`ii'`lhsvar' `rhsvar'_low `rhsvar'_high  `controls`lhsvar'`rhsvar'' if award > 0 & award < 50, absorb(tina t_i_FE) vce(cluster tina)
    
    * store results
    eststo reg_`iteration'_`rhsvar'_`ii'
    replace b_`lhsvar'_`rhsvar'_low	= _b[`rhsvar'_low]  if _n == `ii'+1
    replace se_`lhsvar'_`rhsvar'_low = _se[`rhsvar'_low]    if _n == `ii'+1
    replace b_`lhsvar'_`rhsvar'_high	= _b[`rhsvar'_high] if _n == `ii'+1
    replace se_`lhsvar'_`rhsvar'_high = _se[`rhsvar'_high]  if _n == `ii'+1
    
    * test for differences
    test `rhsvar'_low = `rhsvar'_high
    replace ptest_`lhsvar' = r(p) if _n == `i'+1
    
    return list
    local p_value = r(p)
    
    local excel_number = `i' + 2

    putexcel set "${path_results}/tables/Table_2/Table_`lhsvar'_`rhsvar'_`state'_hac.xlsx", modify
    putexcel B`excel_number' = (`p_value')
    putexcel close
	
  }
   
  * store table in a tex file
  esttab reg_`iteration'_`rhsvar'_* using "${path_results}/tables/Table_2/Table_`lhsvar'_`rhsvar'_`state'_y.tex", replace se sca(N) nonum b(2) se(2) sfmt(0) obslast star(* 0.10 ** 0.05 *** 0.01)
  eststo clear
   
		}
	}
}

*********************************************************
** Table C3: Further heterogeneous effects procurement 
** contract awards on firm investment and employment
*********************************************************

** State-Dependencies

forvalues alt = 1/2 {

global state = `alt'

use "${path_work}/auxiliary/annual_analysis_intensive.dta", clear

* Create dummy for award variable
gen winner = (award>0)

if ($state == 1) {

	local state	= "new_winner"
	local low	= "not_new_winner"
	local high	= "new_winner"

	** new winner
	preserve
	collapse (sum) award, by(tina year)
	keep if award > 0
	bysort tina: keep if _n == 1
	drop award
	save "${path_work}/auxiliary/collapsed_new_winner", replace
	restore

	merge 1:1 tina year using "${path_work}/auxiliary/collapsed_new_winner.dta"
	gen new_winner = 1 if _merge == 3
	replace new_winner = 0 if _merge == 1
	drop if _merge == 2
	drop _merge
	
	cap gen state = new_winner
}

if ($state == 2) {
	
	local state	= "construction_medical"
	local low	= "not_construction_medical"
	local high	= "construction_medical"

	** construction
	gen construction_medical	= 0 if cpv_flag != "45" & cpv_flag != "33"
	replace construction_medical	= 1 if cpv_flag == "45" | cpv_flag == "33"
	
	cap gen state	= construction_medical
}

/*

if ($state == 3) {

	local state	= "competitors"
	local low	= "few_competitors"
	local high	= "more_competitors"

	** competitors
	gen competitors	     = 0 if number_concorrentes < 3
	replace competitors  = 1 if number_concorrentes >= 3

	cap gen state	= competitors
}

*/

** Analysis

********************
*    Preamble      *
********************

* number of years for the horizon
local horizon = 2
local mh = 0

* number of lags for control variables
local lags = 1

* key independent variable
local rhsvarlist award

* list of credit variables to be analyzed
local creditvarlist valor_efectivo ncassets

* list of balance sheet variables to be analyzed
local balancevarlist employees 

* define full list of variables to use as lhsvar
local allvarlist `creditvarlist' `balancevarlist'

*****************************
* Data preparation for IRFs *
*****************************

* compute forward change of credit variables as growth rate relative to period t-1
foreach lhsvar in `balancevarlist' {
  
  forvalues i = `mh'(1)`horizon' {
	
	if (`i'<0){
		local ii = `i' + abs(`mh')
		local ll = abs(`i')
		gen F`ii'`lhsvar' = (L`ll'.`lhsvar' - L.`lhsvar')/ L.`lhsvar'*100
	}
	
	else {
		local ii = `i' + abs(`mh')
		gen F`ii'`lhsvar' = (F`i'.`lhsvar' - L.`lhsvar')/ L.`lhsvar'*100
	}
  }
}

foreach lhsvar in `creditvarlist' {
  forvalues i =  `mh'(1)`horizon' {
    if (`i'<0){
	local ii = `i' + abs(`mh')
	local ll = abs(`i')
	gen F`ii'`lhsvar' = (L`ll'.`lhsvar' - L.`lhsvar')/ L.B001*100
	}
    else {
	local ii = `i' + abs(`mh')
	gen F`ii'`lhsvar' = (F`i'.`lhsvar' - L.`lhsvar')/ L.B001*100
	}
  }
}

* State dependent variables

* daward
foreach lhsvar in `rhsvarlist' {
	gen `lhsvar'_high = `lhsvar' * `state'
	gen `lhsvar'_low  = `lhsvar' * (1 - `state')
}

foreach lhsvar in `allvarlist' {
  forvalues i =  `mh'(1)`horizon' {
  	local ii = `i' + abs(`mh')
  	gen F`ii'`lhsvar'_high = F`ii'`lhsvar' * `state'
	gen F`ii'`lhsvar'_low  = F`ii'`lhsvar' * (1 - `state')
  }
}



* list of control variables (attention F2 is F(abs(`mh'))) !
foreach lhsvar in `allvarlist' {
    
    local controls`lhsvar'award l(1/`lags').award_low l(1/`lags').award_high l(1/`lags').F0`lhsvar'_low l(1/`lags').F0`lhsvar'_high
 
 }

* storing variables
foreach lhsvar in `allvarlist' {
  foreach rhsvar in `rhsvarlist' {
    cap gen b_`lhsvar'_`rhsvar'_low   = .
    cap gen se_`lhsvar'_`rhsvar'_low  = .
    cap gen b_`lhsvar'_`rhsvar'_high  = .
    cap gen se_`lhsvar'_`rhsvar'_high = .
  }
cap gen ptest_`lhsvar' = .
cap gen hacph_`lhsvar' = .
cap gen arph_`lhsvar'  = .
}

***********************
* Regression Analysis *
***********************
local iteration = 0

foreach lhsvar in `creditvarlist' {
local iteration = `iteration' + 1
  foreach rhsvar in `rhsvarlist' {
  
  forvalues i = `mh'(1)`horizon' {
    
    local ii = `i' + abs(`mh')
    
    * run local projections
    reghdfe F`ii'`lhsvar' `rhsvar'_low `rhsvar'_high  `controls`lhsvar'`rhsvar'' if award > 0 &  award < 50, absorb(tina t_i_FE) vce(cluster tina)
    
    * store results
    eststo reg_`iteration'_`rhsvar'_`ii'
    replace b_`lhsvar'_`rhsvar'_low	= _b[`rhsvar'_low]   if _n == `ii'+1
    replace se_`lhsvar'_`rhsvar'_low    = _se[`rhsvar'_low]  if _n == `ii'+1
    replace b_`lhsvar'_`rhsvar'_high	= _b[`rhsvar'_high]  if _n == `ii'+1
    replace se_`lhsvar'_`rhsvar'_high   = _se[`rhsvar'_high] if _n == `ii'+1
    
    * test for differences
    test `rhsvar'_low = `rhsvar'_high
    replace ptest_`lhsvar' = r(p) if _n == `i'+1
    
    return list
    local p_value = r(p)
    
    local excel_number = `i' + 2

    putexcel set "${path_results}/tables/Table_C3/Table_`lhsvar'_`rhsvar'_`state'_hac.xlsx", modify
    putexcel B`excel_number' = (`p_value')
    putexcel close

    
  }
  
  * store table in a tex file
  esttab reg_`iteration'_`rhsvar'_* using "${path_results}/tables/Table_C3/Table_`lhsvar'_`rhsvar'_`state'_y.tex", replace se sca(N) nonum b(2) se(2) sfmt(0) obslast star(* 0.10 ** 0.05 *** 0.01)
  eststo clear
  
  * produce graphs
  cap gen periods = _n - 1 + `mh' if _n <= (`horizon' + abs(`mh')+1)
  cap gen zero = 0 if _n <= (`horizon' + abs(`mh')+1)
  
  * confidence bands
  scalar sig1 = 0.05
  scalar sig2 = 0.10
  
  cap gen up1_`lhsvar'_`rhsvar'_low = b_`lhsvar'_`rhsvar'_low + invnormal(1-sig1/2)*se_`lhsvar'_`rhsvar'_low if _n <= (`horizon'+ abs(`mh') + 1)
  cap gen up2_`lhsvar'_`rhsvar'_low = b_`lhsvar'_`rhsvar'_low + invnormal(1-sig2/2)*se_`lhsvar'_`rhsvar'_low if _n <= (`horizon'+ abs(`mh') + 1)
  cap gen dn1_`lhsvar'_`rhsvar'_low = b_`lhsvar'_`rhsvar'_low - invnormal(1-sig1/2)*se_`lhsvar'_`rhsvar'_low if _n <= (`horizon'+ abs(`mh') + 1)
  cap gen dn2_`lhsvar'_`rhsvar'_low = b_`lhsvar'_`rhsvar'_low - invnormal(1-sig2/2)*se_`lhsvar'_`rhsvar'_low if _n <= (`horizon'+ abs(`mh') + 1)
  
  
  cap gen up1_`lhsvar'_`rhsvar'_high = b_`lhsvar'_`rhsvar'_high + invnormal(1-sig1/2)*se_`lhsvar'_`rhsvar'_high if _n <= (`horizon'+ abs(`mh') + 1)
  cap gen up2_`lhsvar'_`rhsvar'_high = b_`lhsvar'_`rhsvar'_high + invnormal(1-sig2/2)*se_`lhsvar'_`rhsvar'_high if _n <= (`horizon'+ abs(`mh') + 1)
  cap gen dn1_`lhsvar'_`rhsvar'_high = b_`lhsvar'_`rhsvar'_high - invnormal(1-sig1/2)*se_`lhsvar'_`rhsvar'_high if _n <= (`horizon'+ abs(`mh') + 1)
  cap gen dn2_`lhsvar'_`rhsvar'_high = b_`lhsvar'_`rhsvar'_high - invnormal(1-sig2/2)*se_`lhsvar'_`rhsvar'_high if _n <= (`horizon'+ abs(`mh') + 1)
  
  }
}

* BALANCE SHEET VARIABLES - OWN GROWTH

local iteration = 0

foreach lhsvar in `balancevarlist' {
	
local iteration = `iteration' + 1
  
  foreach rhsvar in `rhsvarlist' {
  
  forvalues i = `mh'(1)`horizon' {
    
    local ii = `i' + abs(`mh')
    
    * run local projections
    reghdfe F`ii'`lhsvar' `rhsvar'_low `rhsvar'_high  `controls`lhsvar'`rhsvar'' if award > 0 & award < 50, absorb(tina t_i_FE) vce(cluster tina)
    
    * store results
    eststo reg_`iteration'_`rhsvar'_`ii'
    replace b_`lhsvar'_`rhsvar'_low	= _b[`rhsvar'_low]  if _n == `ii'+1
    replace se_`lhsvar'_`rhsvar'_low = _se[`rhsvar'_low]    if _n == `ii'+1
    replace b_`lhsvar'_`rhsvar'_high	= _b[`rhsvar'_high] if _n == `ii'+1
    replace se_`lhsvar'_`rhsvar'_high = _se[`rhsvar'_high]  if _n == `ii'+1
    
    * test for differences
    test `rhsvar'_low = `rhsvar'_high
    replace ptest_`lhsvar' = r(p) if _n == `i'+1
    
    return list
    local p_value = r(p)
    
    local excel_number = `i' + 2

    putexcel set "${path_results}/tables/Table_C3/Table_`lhsvar'_`rhsvar'_`state'_hac.xlsx", modify
    putexcel B`excel_number' = (`p_value')
    putexcel close
	
  }
   
  * store table in a tex file
  esttab reg_`iteration'_`rhsvar'_* using "${path_results}/tables/Table_C3/Table_`lhsvar'_`rhsvar'_`state'_y.tex", replace se sca(N) nonum b(2) se(2) sfmt(0) obslast star(* 0.10 ** 0.05 *** 0.01)
  eststo clear
   
		}
	}
}

*********************************************************
