* Author(s)    :  Ricardo Gabriel
* Date         :  07/10/2021
* Update       :  15/09/2022
* Description  :  Regression analysis (lp did)
* Dependencies :  ${path_work}/Annual_Contest.dta
* Modifications:  Change background, remove one horizon
* Products     :  log files, pdf figures, latex files in results folder.

* NEW VERSION
* Modifications:  (25/03/2024, João Quelhas, creation of replication package)

*********************************************************
*                       Preamble                        *
*********************************************************

local color "white"
local scale = 2

grstyle init
grstyle set plain, nogrid noextend
grstyle graphsize x 12
grstyle graphsize y 6
grstyle yesno draw_major_vgrid yes
grstyle color background white
grstyle color dkorange

*********************************************************
*                          LP DiD                       *
*********************************************************

** Produce List of losers
*********************************************************

* Upload BASE dataset.
use "${path_source}/PM111_A_BASE_BPLIM.dta", clear

* Rename the variable.
rename adjudicatario_tina tina
rename preco award

* Format the siganture date as date.
replace date_signature = dofm(date_signature)

* Keep public contests.
noi: keep if inrange(procedimento,5,7)

* Keep positive awards.
noi: keep if award > 0

* Keep contests with solely one winner.
noi: keep if number_adjudicatarios == 1

* Replace prazo if it is more than 10 years.
replace prazo = 3650 if prazo > 3650

preserve

collapse (sum) award, by(tina year)

keep if award > 0

drop award

gen winner = 1

unique tina

sum tina

sort tina year

expand 3

bys tina year: gen obs = _n

replace year = year + 1 if obs == 2

replace year = year + 2 if obs == 3

duplicates drop tina year, force

drop obs

save "${path_work}/auxiliary/tina_winners", replace

restore

* Keep the firm identifier and other contestants.
keep concorrentes_tina*

* Generate an id.
gen obs = _n

* Reshape the dataset.
reshape long concorrentes_tina, i(obs) j(conc)

* Rename the contestants firm identifier.
rename concorrentes_tina tina

* Generate variable losers.
gen long losers = tina

* Drop variables not needed.
drop obs conc
drop if tina==.

* Drop duplicates.
duplicates drop tina, force

*Sort the dataset.
sort tina

* Merge the dataset with winners to exclude those.
merge 1:m tina using "${path_work}/auxiliary/tina_winners.dta"

* Keep only the ones that are not winners.
keep if _merge == 1

drop _merge losers winner year

gen winner = 0

sum tina

* Save the dataset.
save "${path_work}/auxiliary/tina_losers.dta", replace


use "${path_work}/auxiliary/tina_losers.dta", clear

append using "${path_work}/auxiliary/tina_winners.dta"

noi: drop if year < 2009
replace year = 2009 if year == .
xtset tina year
tsfill, full
sort tina year
replace winner = 0 if winner ==.

merge 1:1 tina year using "${path_work}/annual_dataset/CBHP_A.dta"
drop if _merge == 2
drop _merge
merge m:m tina using "${path_work}/annual_dataset/Cover_Unique.dta"
drop if _merge == 2
drop _merge
merge 1:1 tina year using "${path_work}/annual_dataset/Credit_A_Last.dta"
drop if _merge == 2
drop _merge

xtset tina year

save "${path_work}/auxiliary/lp_did_merged.dta", replace

use "${path_work}/auxiliary/lp_did_merged.dta", clear

* Set the panel with firm identifier and year.
xtset tina year

* Adjust sample to include only data from 2009 to 2019.
* noi: drop if year < 2009 | year > 2019

* Adjust sample to include only private non-financial corporations.
noi: keep if si_final == 348500004

* Adjust sample to include only firms "em atividade" (in activity).
noi: drop if sitempresa > 1

* Adjust sample to include only firms with available information on lagged assets.
noi: drop if l.B001 == . 

* Adjust sample to include only firms with lagged total assets above p1.
noi: sum l.B001,d
noi: drop if l.B001 <= `r(p1)'

* Drop if the lagged value of a firm has no employees.
noi: drop if l.E002 == 0

* Set the panel with firm identifier and year.
xtset tina year

* Create all the required variables related to fundamentals of the firms.
gen ncassets	 = B004 	        // non-current assets
gen cash 	 = B049		        // current assets -> cash and bank deposits
gen employees	 = E002		        // number of paid employees

* Compute the implicit interest rate

* The first step is to remove negative interest payments.
noi: replace D053 = . if D053 <= 0

* Compute the interest rate using different formulas:
** = interest rate expense / credit that a firm used effectively
noi: gen interest  = D053 / L.valor_efectivo
** = interest rate expense / lag of credit that a firm used effectively

* Summarize the variable interest.
noi: sum interest*,d

* Winsorize the variable interest between 10% and 90%.
noi: winsor2 interest, replace cuts(10 90)
* Convert the interest rate to percentage.
replace interest = interest * 100

*bys tina: gen obs = _N
*sum obs
*keep if obs == `r(max)'

** LD DID

*replace valor_efectivo =  valor_efectivo / L.B001

xtset tina year

tabulate year, gen(year_dummy)

gen Lwinner = L.winner

local allvarlist valor_efectivo ncassets employees

foreach var in `allvarlist' { 
	
	gen log_`var' = log(`var')*100

	gen Llog_`var' = L.log_`var'

	lpdid log_`var', time(year) unit(tina) treat(winner) pre(2) post(2) nevertreated controls(year_dummy* Lwinner Llog_`var')

	graph export "${path_results}/figures/figure_c_2/lp_did_`var'.pdf", as(pdf) replace

	}

*********************************************************
